@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 57795 2009-01-02 21:47:50Z CJP $"
-__revision__ = "$Revision: 57795 $"
+__svnid__ = "$Id: Editra.py 59754 2009-03-23 01:01:11Z CJP $"
+__revision__ = "$Revision: 59754 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -96,6 +96,9 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._lock = False
         self._windows = dict()
 
+        # Disable debug popups
+        wx.Log.EnableLogging(False)
+
         if ed_glob.SINGLE:
             # Setup the instance checker
             instance_name = u"%s-%s" % (self.GetAppName(), wx.GetUserId())
@@ -196,6 +199,14 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
         self.Bind(ed_ipc.EVT_COMMAND_RECV, self.OnCommandRecieved)
 
+        # Splash a warning if version is not a final version
+        if profiler.Profile_Get('APPSPLASH'):
+            import edimage
+            splash_img = edimage.splashwarn.GetBitmap()
+            self.splash = wx.SplashScreen(splash_img, wx.SPLASH_CENTRE_ON_PARENT | \
+                                          wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
+            self.splash.Show()
+
         return True
 
     def Destroy(self):
@@ -207,6 +218,14 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             pass
         wx.App.Destroy(self)
 
+    def DestroySplash(self):
+        """Destroy the splash screen"""
+        # If is created and not dead already
+        if getattr(self, 'splash', None) is not None and \
+           isinstance(self.splash, wx.SplashScreen):
+            self.splash.Destroy()
+            self.splash = None
+
     def Exit(self, force=False):
         """Exit the program
         @postcondition: If no toplevel windows are present program will exit.
@@ -360,6 +379,10 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         self._lock = True
 
+    def MacNewFile(self):
+        """Stub for future use"""
+        pass
+
     def MacOpenFile(self, filename):
         """Macintosh Specific code for opening files that are associated
         with the editor and double clicked on after the editor is already
@@ -387,6 +410,21 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         else:
             pass
 
+    def MacPrintFile(self, filename):
+        """Stub for future use
+        @param filename: file to print
+
+        """
+        pass
+
+    def MacReopenApp(self):
+        """Handle kAEReopenApplication when dock icons is clicked on"""
+        frame = self.GetTopWindow()
+        if frame is not None:
+            if frame.IsIconized():
+                frame.Iconize(False)
+            frame.Raise()
+
     def OnActivate(self, evt):
         """Activation Event Handler
         @param evt: event that called this handler
@@ -395,6 +433,11 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         """
         if evt.GetActive():
             self._log("[app][info] I'm Awake!!")
+#            frame = self.GetTopWindow()
+#            if frame is not None:
+#                if frame.IsIconized():
+#                    frame.Iconize(False)
+#                frame.Raise()
         else:
             self._log("[app][info] Going to sleep")
         evt.Skip()
@@ -479,6 +522,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
     def OpenNewWindow(self, fname=u'', caller=None):
         """Open a new window
         @keyword fname: Open a file in the new window
+        @return: the new window
 
         """
         frame = ed_main.MainWindow(None, wx.ID_ANY,
@@ -498,6 +542,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         # this doesn't happen automatically on windows
         if wx.Platform == '__WXMSW__':
             wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
+        return frame
 
     def OnNotify(self, evt):
         """Handle notification events
@@ -507,6 +552,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         e_val = evt.GetValue()
         if evt.GetId() == ID_UPDATE_CHECK and \
            isinstance(e_val, tuple) and e_val[0]:
+            self.DestroySplash()
             mdlg = wx.MessageDialog(self.GetActiveWindow(),
                                     _("An updated version of Editra is available\n"
                                       "Would you like to download Editra %s now?") %\
@@ -656,6 +702,12 @@ def InitConfig():
             # Keep for now till plugins are updated
             #profiler.Profile_Del('EOL') # changed to EOL_MODE
 
+            # After 0.4.65 LAST_SESSION now points a session file and not
+            # to a list of files to open.
+            sess = profiler.Profile_Get('LAST_SESSION')
+            if isinstance(sess, list):
+                profiler.Profile_Set('LAST_SESSION', u'')
+
             #---- End Temporary Profile Adaptions ----#
 
             # Write out updated profile
@@ -663,7 +715,7 @@ def InitConfig():
 
             # When upgrading from an older version make sure all
             # config directories are available.
-            for cfg in ["cache", "styles", "plugins", "profiles"]:
+            for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
                 if not util.HasConfigDir(cfg):
                     util.MakeConfigDir(cfg)
 
@@ -703,7 +755,7 @@ def InitConfig():
             ed_glob.VDEBUG = True
 
     # Resolve resource locations
-    ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
+    ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir(u"")
     ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir(u"pixmaps", True)
     ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir(u"plugins")
     ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join(u"pixmaps", u"theme"))
@@ -714,10 +766,11 @@ def InitConfig():
     ed_glob.CONFIG['TEST_DIR'] = util.ResolvConfigDir(os.path.join(u"tests", u"syntax"), True)
 
     # Make sure all standard config directories are there
-    for cfg in ["cache", "styles", "plugins", "profiles"]:
+    for cfg in ("cache", "styles", "plugins", "profiles", "sessions"):
         if not util.HasConfigDir(cfg):
             util.MakeConfigDir(cfg)
     ed_glob.CONFIG['CACHE_DIR'] = util.ResolvConfigDir(u"cache")
+    ed_glob.CONFIG['SESSION_DIR'] = util.ResolvConfigDir(u"sessions")
 
     return profile_updated
 
@@ -891,23 +944,8 @@ def _Main(opts, args):
         editra_app.Destroy()
         os._exit(0)
 
-    if editra_app.GetProfileUpdated():
-        # Make sure window iniliazes to default position
-        profiler.Profile_Del('WPOS')
-        wx.MessageBox(_("Your profile has been updated to the latest "
-                        "version") + u"\n" + \
-                      _("Please check the preferences dialog to check "
-                        "your preferences"),
-                      _("Profile Updated"))
-
-    # Splash a warning if version is not a final version
-    if profiler.Profile_Get('APPSPLASH'):
-        import edimage
-        splash_img = edimage.splashwarn.GetBitmap()
-        splash = wx.SplashScreen(splash_img, wx.SPLASH_CENTRE_ON_PARENT | \
-                                 wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
-        splash.Show()
-        wx.CallLater(2500, splash.Destroy)
+    # Set the timeout on destroying the splash screen
+    wx.CallLater(2300, editra_app.DestroySplash)
 
     if profiler.Profile_Get('SET_WSIZE'):
         wsize = profiler.Profile_Get('WSIZE')
@@ -922,7 +960,8 @@ def _Main(opts, args):
     # Load Session Data
     # But not if there are command line args for files to open
     if profiler.Profile_Get('SAVE_SESSION', 'bool', False) and not len(args):
-        frame.GetNotebook().LoadSessionFiles()
+        session = profiler.Profile_Get('LAST_SESSION', default=u'')
+        frame.GetNotebook().LoadSessionFile(session)
 
     # Unlike wxMac/wxGTK Windows doesn't post an activate event when a window
     # is first shown, so do it manually to make sure all event handlers get
@@ -944,6 +983,17 @@ def _Main(opts, args):
         except IndexError:
             dev_tool.DEBUGP("[main][err] IndexError on commandline args")
 
+    # Notify that profile was updated
+    if editra_app.GetProfileUpdated():
+        editra_app.DestroySplash()
+        # Make sure window iniliazes to default position
+        profiler.Profile_Del('WPOS')
+        wx.MessageBox(_("Your profile has been updated to the latest "
+                        "version") + u"\n" + \
+                      _("Please check the preferences dialog to check "
+                        "your preferences"),
+                      _("Profile Updated"))
+
     # 3. Start Applications Main Loop
     dev_tool.DEBUGP("[main][info] Starting MainLoop...")
     wx.CallAfter(frame.Raise)
