@@ -16,8 +16,8 @@ deduct the requested information.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: pycomp.py 57700 2008-12-31 22:44:51Z CJP $"
-__revision__ = "$Revision: 57700 $"
+__cvsid__ = "$Id: pycomp.py 59583 2009-03-17 03:49:44Z CJP $"
+__revision__ = "$Revision: 59583 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -25,7 +25,7 @@ import os
 import sys
 import tokenize
 import types
-from token import NAME, DEDENT, STRING, NEWLINE
+from token import NAME, DEDENT, STRING
 
 import wx
 from wx.py import introspect
@@ -36,24 +36,26 @@ from wx.py import introspect
 # of each character instead of each actual token which causes the parse to fail.
 from StringIO import StringIO
 
+# Local imports
+import completer
+
 #--------------------------------------------------------------------------#
 
-class Completer(object):
+class Completer(completer.BaseCompleter):
     """Code completer provider"""
     def __init__(self, stc_buffer):
         """Initiliazes the completer
         @param stc_buffer: buffer that contains code
 
         """
-        object.__init__(self)
-        self._log = wx.GetApp().GetLog()
-        self._buffer = stc_buffer
-        self._autocomp_keys = [ord('.'),]
-        self._autocomp_stop = ' \'"\\`):'
-        self._autocomp_fillup = '.,;([]}<>%^&+-=*/|'
-        self._calltip_keys = [ord('('),]
-        self._calltip_cancel = [ord(')'), wx.WXK_RETURN]
-        self._case_sensitive = False
+        completer.BaseCompleter.__init__(self, stc_buffer)
+
+        # Setup
+        self.SetAutoCompKeys([ord('.'), ])
+        self.SetAutoCompStops(' \'"\\`):')
+        self.SetAutoCompFillups('.,;([]}<>%^&+-=*/|')
+        self.SetCallTipKeys([ord('('), ])
+        self.SetCallTipCancel([ord(')'), wx.WXK_RETURN])
 
         # Needed for introspect to run
         try:
@@ -102,23 +104,7 @@ class Completer(object):
             self._log("[pycomp][err] _GetCompletionInfo: %s, %s" % \
                       (sys.exc_info()[0], sys.exc_info()[1]))
             return ''
-
-    def GetAutoCompKeys(self):
-        """Returns the list of key codes for activating the
-        autocompletion.
-        @return: list of autocomp activation keys
-
-        """
-        if hasattr(self, "_autocomp_keys"):
-            return self._autocomp_keys
-        else:
-            return list()
         
-    def IsAutoCompEvent(self, evt):
-        if evt.ControlDown() and evt.GetKeyCode() == wx.WXK_SPACE:
-            return True
-        return False
-
     def GetAutoCompList(self, command):
         """Returns the list of possible completions for a 
         command string. If namespace is not specified the lookup
@@ -129,68 +115,20 @@ class Completer(object):
         """
         return self._GetCompletionInfo(command)
 
-    def GetAutoCompStops(self):
-        """Returns a string of characters that should cancel
-        the autocompletion lookup.
-        @return: string of keys that will cancel autocomp/calltip actions
-
-        """
-        return self._autocomp_stop
-    
-    def GetAutoCompFillups(self):
-        return self._autocomp_fillup
-
     def GetCallTip(self, command):
         """Returns the formated calltip string for the command.
         If the namespace command is unset the locals namespace is used.
         @param command: command to get calltip for
-        @keyword namespace: namespace to do lookup in
 
         """
         return self._GetCompletionInfo(command, calltip=True)
 
-    def GetCallTipKeys(self):
-        """Returns the list of keys to activate a calltip on
-        @return: list of keys that can activate a calltip
-
-        """
-        return self._calltip_keys
-
-    def GetCallTipCancel(self):
-        """Get the list of key codes that should stop a calltip"""
-        return self._calltip_cancel
-
-    def IsCallTipEvent(self, evt):
-        """@todo: How is this used?"""
-        if evt.ControlDown() and evt.GetKeyCode() == ord('9'):
-            return True
-        return False
-
-    def GetCaseSensitive(self):
-        """Returns whether the autocomp commands are case sensitive
-        or not.
-        @return: whether lookup is case sensitive or not
-
-        """
-        return self._case_sensitive
-
-    def SetCaseSensitive(self, value):
-        """Sets whether the completer should be case sensitive
-        or not, and returns True if the value was set.
-        @param value: toggle case sensitivity
-
-        """
-        if isinstance(value, bool):
-            self._case_sensitive = value
-            return True
-        else:
-            return False
-
 #-----------------------------------------------------------------------------#
 # This code below is a modified and adapted version of the pythoncomplete 
 # Omni completion script for vim. The original vimscript can be found at the 
 # following address: http://www.vim.org/scripts/script.php?script_id=1542
-dbg = wx.GetApp().GetLog()
+def dbg(msg):
+    wx.GetApp().GetLog()(msg)
 
 class PyCompleter(object):
     """Python code completion provider"""
@@ -747,7 +685,7 @@ class PyParser:
             # NOTE: This part of the parse is where the problem is happening
             assign += token
             level = 0
-            tstack = list()
+#            tstack = list()
             while True:
                 tokentype, token = self.next()[:-1]
 #                tstack.append((assign, token, level))
