@@ -12,8 +12,8 @@ Tools and Utilities for debugging and helping with development of Editra.
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 57699 2008-12-31 20:27:56Z CJP $"
-__revision__ = "$Revision: 57699 $"
+__svnid__ = "$Id: dev_tool.py 59092 2009-02-22 19:13:56Z CJP $"
+__revision__ = "$Revision: 59092 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -24,6 +24,9 @@ import platform
 import traceback
 import time
 import webbrowser
+import codecs
+import locale
+import types
 import wx
 
 # Editra Libraries
@@ -35,6 +38,15 @@ import ed_msg
 _ = wx.GetTranslation
 RE_LOG_LBL = re.compile(r"\[(.+?)\]")
 
+# The default fallback encoding
+DEFAULT_ENCODING = locale.getpreferredencoding()
+try:
+    codecs.lookup(DEFAULT_ENCODING)
+except (LookupError, TypeError):
+    DEFAULT_ENCODING = 'utf-8'
+
+PYTHONW = 'pythonw' in sys.executable.lower()
+
 #-----------------------------------------------------------------------------#
 # General Debuging Helper Functions
 
@@ -74,7 +86,8 @@ def DEBUGP(statement):
         msg = LogMsg(info)
 
     # Only print to stdout when DEBUG is active
-    if ed_glob.DEBUG:
+    # Cant print to stdio if using pythonw
+    if ed_glob.DEBUG and not PYTHONW:
         mstr = unicode(msg)
         print mstr.encode('utf-8', 'replace')
 
@@ -147,7 +160,7 @@ class LogMsg(object):
 
     def __str__(self):
         """Returns a nice formatted string version of the message"""
-        statement = unicode(self._msg['mstr'])
+        statement = DecodeString(self._msg['mstr'])
         s_lst = [u"[%s][%s][%s]%s" % (self.ClockTime, self._msg['msrc'],
                                       self._msg['lvl'], msg) 
                  for msg in statement.split(u"\n")
@@ -195,6 +208,28 @@ class LogMsg(object):
 
 #-----------------------------------------------------------------------------#
 
+def DecodeString(string, encoding=None):
+    """Decode the given string to Unicode using the provided
+    encoding or the DEFAULT_ENCODING if None is provided.
+    @param string: string to decode
+    @keyword encoding: encoding to decode string with
+
+    """
+    if encoding is None:
+        encoding = DEFAULT_ENCODING
+
+    if not isinstance(string, types.UnicodeType):
+        try:
+            rtxt = codecs.getdecoder(encoding)(string)[0]
+        except Exception, msg:
+            rtxt = string
+        return rtxt
+    else:
+        # The string is already unicode so just return it
+        return string
+
+#-----------------------------------------------------------------------------#
+
 def EnvironmentInfo():
     """Returns a string of the systems information
     @return: System information string
