@@ -35,21 +35,27 @@ eclib.ctrlbox
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: finddlg.py 57805 2009-01-03 02:01:17Z CJP $"
-__revision__ = "$Revision: 57805 $"
+__svnid__ = "$Id: finddlg.py 59519 2009-03-13 21:10:54Z CJP $"
+__revision__ = "$Revision: 59519 $"
 
 __all__ = ["FindBox", "FindEvent", "FindPanel", "FindReplaceDlg",
-           "MiniFindReplaceDialog", "AdvFindReplaceDlg",
+           "MiniFindReplaceDlg", "AdvFindReplaceDlg",
+
            "AFR_STYLE_FINDDIALOG", "AFR_STYLE_REPLACEDIALOG",
-           "AFR_STYLE_NON_FLOATING", "AFR_UP", "AFR_WHOLEWORD", 
+           "AFR_STYLE_NON_FLOATING",
+           
+           "AFR_UP", "AFR_WHOLEWORD", 
            "AFR_MATCHCASE", "AFR_REGEX", "AFR_RECURSIVE", "AFR_NOLOOKIN",
            "AFR_NOUPDOWN", "AFR_NOWHOLEWORD", "AFR_NOMATCHCASE", "AFR_NOREGEX",
-           "AFR_NOFILTER", "AFR_NOOPTIONS", "LOCATION_CURRENT_DOC", 
-           "LOCATION_OPEN_DOCS", "LOCATION_IN_FILES", "LOCATION_MAX", 
+           "AFR_NOFILTER", "AFR_NOOPTIONS",
+
+           "LOCATION_CURRENT_DOC",
+           "LOCATION_OPEN_DOCS", "LOCATION_IN_FILES", "LOCATION_MAX",
+
            "edEVT_FIND_CLOSE", "EVT_FIND_CLOSE", "edEVT_FIND", "EVT_FIND",
            "edEVT_FIND_NEXT", "EVT_FIND_NEXT", "edEVT_FIND_ALL", "EVT_FIND_ALL",
            "edEVT_REPLACE", "EVT_REPLACE", "edEVT_REPLACE_ALL",
-           "EVT_REPLACE_ALL"]
+           "EVT_REPLACE_ALL", "EVT_OPTION_CHANGED", "edEVT_OPTION_CHANGED"]
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -344,6 +350,7 @@ class FindReplaceDlgBase:
 
         # Event handlers
         self.Bind(_EVT_MODE_CHANGE, self._OnModeChange)
+        self.Bind(_EVT_DO_CLOSE_DLG, lambda evt: self._SendCloseEvent())
         self.Bind(wx.EVT_MENU, lambda evt: self._SendCloseEvent(), id=wx.ID_CLOSE)
         self.Bind(wx.EVT_SET_FOCUS,
                   lambda evt: self._panel.SetFocus() and evt.Skip())
@@ -623,7 +630,7 @@ class FindBox(ctrlbox.ControlBox):
         """
         self._fpanel.SetFindMode(find)
         self.Layout()
-        evt = _DlgModeChange(self.GetId(), _edEVT_MODE_CHANGE)
+        evt = _AdvFindDlgInternalEvent(self.GetId(), _edEVT_MODE_CHANGE)
         wx.PostEvent(self.GetParent(), evt)
 
     def SetReplaceBitmap(self, bmp):
@@ -683,6 +690,12 @@ class FindPanel(wx.Panel):
             self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUI, id=bid)
         self.Bind(wx.EVT_SET_FOCUS, lambda evt: self.__SetFocus())
         self._ftxt.Bind(wx.EVT_SET_FOCUS, lambda evt: self._ftxt.SelectAll())
+        self._rtxt.Bind(wx.EVT_SET_FOCUS, lambda evt: self._rtxt.SelectAll())
+
+        # Key handling HACK for windows
+        if wx.Platform == '__WXMSW__':
+            for child in self.GetChildren():
+                child.Bind(wx.EVT_KEY_UP, self._OnKeyUp)
 
     def __SetFocus(self):
         """Set the focus to the find box"""
@@ -724,6 +737,7 @@ class FindPanel(wx.Panel):
         self._sizers['look'] = wx.BoxSizer(wx.VERTICAL)
         li_sz = wx.BoxSizer(wx.HORIZONTAL)
         dirbtn = wx.Button(self, ID_CHOOSE_DIR, u"...", style=wx.BU_EXACTFIT)
+        dirbtn.SetToolTipString(_("Choose Folder"))
         li_sz.AddMany([(self._lookin, 1, wx.ALIGN_CENTER_VERTICAL), ((5, 5), 0),
                        (dirbtn, 0, wx.ALIGN_CENTER_VERTICAL)])
         li_lbl = wx.StaticText(self, label=_("Look in") + u":")
@@ -816,6 +830,16 @@ class FindPanel(wx.Panel):
         recurse.Enable(in_files)
         self.ShowFileFilters(in_files and not (flags & AFR_NOFILTER))
 
+    def _OnKeyUp(self, evt):
+        """Check if the dialog should be closed
+        @note: msw only
+
+        """
+        if evt.GetKeyCode() == wx.WXK_ESCAPE:
+            evt = _AdvFindDlgInternalEvent(self.GetId(), _edEVT_DO_CLOSE_DLG)
+            wx.PostEvent(self.GetTopLevelParent(), evt)
+        evt.Skip()
+
     def _ShowButtons(self, find=True):
         """Toggle the visiblity of a button set
         @param find: Show Find Buttons or Show Replace Buttons
@@ -1171,7 +1195,7 @@ class FindPanel(wx.Panel):
             self.Layout()
 
             # Require additional resizing
-            evt = _DlgModeChange(self.GetId(), _edEVT_MODE_CHANGE)
+            evt = _AdvFindDlgInternalEvent(self.GetId(), _edEVT_MODE_CHANGE)
             wx.PostEvent(self.GetTopLevelParent(), evt)
 
     def ShowLookinCombo(self, show=True):
@@ -1198,7 +1222,10 @@ class FindPanel(wx.Panel):
 _edEVT_MODE_CHANGE = wx.NewEventType()
 _EVT_MODE_CHANGE = wx.PyEventBinder(_edEVT_MODE_CHANGE, 1)
 
-class _DlgModeChange(wx.PyEvent):
+_edEVT_DO_CLOSE_DLG = wx.NewEventType()
+_EVT_DO_CLOSE_DLG = wx.PyEventBinder(_edEVT_DO_CLOSE_DLG, 1)
+
+class _AdvFindDlgInternalEvent(wx.PyEvent):
     def __init__(self, winid=wx.ID_ANY, etype=wx.wxEVT_NULL):
         """Create the Event"""
         wx.PyEvent.__init__(self, winid, etype)
