@@ -22,8 +22,8 @@ after creating the bar to change it.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: pstatbar.py 57345 2008-12-14 23:47:52Z CJP $"
-__revision__ = "$Revision: 57345 $"
+__svnid__ = "$Id: pstatbar.py 59350 2009-03-05 20:10:16Z CJP $"
+__revision__ = "$Revision: 59350 $"
 
 __all__ = ["ProgressStatusBar",]
 
@@ -38,7 +38,7 @@ import wx
 class ProgressStatusBar(wx.StatusBar):
     """Custom StatusBar with a built-in progress bar"""
     def __init__(self, parent, id_=wx.ID_ANY,
-                 style=wx.DEFAULT_STATUSBAR_STYLE,
+                 style=wx.SB_FLAT,
                  name="ProgressStatusBar"):
         """Creates a status bar that can hide and show a progressbar
         in the far right section. The size of the progressbar is also
@@ -216,7 +216,8 @@ class ProgressStatusBar(wx.StatusBar):
 
         """
         if number == self.GetFieldsCount() - 1 and self.IsBusy():
-            self.tmp = txt
+            if self.tmp is None:
+                self.tmp = txt
         else:
             super(ProgressStatusBar, self).SetStatusText(txt, number)
 
@@ -231,7 +232,9 @@ class ProgressStatusBar(wx.StatusBar):
         self.__Reposition()
         bfield = self.GetFieldsCount() - 1
         self.tmp = self.GetStatusText(bfield)
-        self.SetStatusText('', bfield) # Clear the progress field
+        # Clear the progress field so the text doesn't show behind
+        # the progress indicator.
+        super(ProgressStatusBar, self).SetStatusText('', bfield)
         self.stop = False
         self.ShowProgress(True)
         self.Run(rate)
