@@ -18,14 +18,13 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 57427 2008-12-18 21:52:51Z CJP $"
-__revision__ = "$Revision: 57427 $"
+__svnid__ = "$Id: ed_cmdbar.py 59256 2009-03-02 00:52:16Z CJP $"
+__revision__ = "$Revision: 59256 $"
 
 #--------------------------------------------------------------------------#
 # Imports
 import os
 import sys
-import cStringIO, zlib
 import glob
 import re
 import wx
@@ -36,10 +35,7 @@ import ed_glob
 import ed_search
 import ed_event
 import ed_msg
-import eclib.platebtn as platebtn
-import eclib.finddlg as finddlg
-import eclib.txtentry as txtentry
-import eclib.ctrlbox as ctrlbox
+import eclib
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
@@ -69,23 +65,23 @@ ID_REGEX = wx.NewId()
 
 #-----------------------------------------------------------------------------#
 
-class CommandBarBase(ctrlbox.ControlBar):
+class CommandBarBase(eclib.ControlBar):
     """Base class for control bars"""
     def __init__(self, parent):
-        ctrlbox.ControlBar.__init__(self, parent,
-                                    style=ctrlbox.CTRLBAR_STYLE_GRADIENT)
+        eclib.ControlBar.__init__(self, parent,
+                                    style=eclib.CTRLBAR_STYLE_GRADIENT)
 
         if wx.Platform == '__WXGTK__':
-            self.SetWindowStyle(ctrlbox.CTRLBAR_STYLE_DEFAULT)
+            self.SetWindowStyle(eclib.CTRLBAR_STYLE_DEFAULT)
 
         self.SetVMargin(2, 2)
 
         # Attributes
         self._parent = parent
         self.ctrl = None
-        self.close_b = platebtn.PlateButton(self, ID_CLOSE_BUTTON,
-                                            bmp=XButton.GetBitmap(),
-                                            style=platebtn.PB_STYLE_NOBG)
+        self.close_b = eclib.PlateButton(self, ID_CLOSE_BUTTON,
+                                         bmp=XButton.GetBitmap(),
+                                         style=eclib.PB_STYLE_NOBG)
 
         # Setup
         self.AddControl(self.close_b, wx.ALIGN_LEFT)
@@ -138,19 +134,20 @@ class SearchBar(CommandBarBase):
         # Attributes
         self.SetControl(ed_search.EdSearchCtrl(self, wx.ID_ANY,
                                                menulen=5, size=(180, -1)))
+        self._sctrl = self.ctrl.GetSearchController()
 
         # Setup
         f_lbl = wx.StaticText(self, label=_("Find") + u": ")
         t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DOWN), wx.ART_MENU)
-        next_btn = platebtn.PlateButton(self, ID_SEARCH_NEXT, _("Next"),
-                                        t_bmp, style=platebtn.PB_STYLE_NOBG)
+        next_btn = eclib.PlateButton(self, ID_SEARCH_NEXT, _("Next"),
+                                     t_bmp, style=eclib.PB_STYLE_NOBG)
         self.AddControl(f_lbl, wx.ALIGN_LEFT)
         self.AddControl(self.ctrl, wx.ALIGN_LEFT)
         self.AddControl(next_btn, wx.ALIGN_LEFT)
 
         t_bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_UP), wx.ART_MENU)
-        pre_btn = platebtn.PlateButton(self, ID_SEARCH_PRE, _("Previous"),
-                                       t_bmp, style=platebtn.PB_STYLE_NOBG)
+        pre_btn = eclib.PlateButton(self, ID_SEARCH_PRE, _("Previous"),
+                                    t_bmp, style=eclib.PB_STYLE_NOBG)
         self.AddControl(pre_btn, wx.ALIGN_LEFT)
 
         match_case = wx.CheckBox(self, ID_MATCH_CASE, _("Match Case"))
@@ -172,9 +169,11 @@ class SearchBar(CommandBarBase):
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
+        self._sctrl.RegisterClient(self)
 
     def __del__(self):
         ed_msg.Unsubscribe(self.OnThemeChange)
+        self._sctrl.RemoveClient(self)
 
     def OnButton(self, evt):
         """Handle button clicks for the next/previous buttons
@@ -197,9 +196,9 @@ class SearchBar(CommandBarBase):
             ctrl = self.FindWindowById(e_id)
             if ctrl != None:
                 if e_id == ID_MATCH_CASE:
-                    flag = finddlg.AFR_MATCHCASE
+                    flag = eclib.AFR_MATCHCASE
                 else:
-                    flag = finddlg.AFR_REGEX
+                    flag = eclib.AFR_REGEX
 
                 if self.ctrl != None:
                     if ctrl.GetValue():
@@ -209,6 +208,15 @@ class SearchBar(CommandBarBase):
         else:
             evt.Skip()
 
+    def NotifyOptionChanged(self, evt):
+        """Callback for L{ed_search.SearchController} to notify of update
+        to the find options.
+        @param evt: eclib.finddlg.FindEvent
+
+        """
+        self.FindWindowById(ID_MATCH_CASE).SetValue(evt.IsMatchCase())
+        self.FindWindowById(ID_REGEX).SetValue(evt.IsRegEx())
+
     def OnThemeChange(self, msg):
         """Update icons when the theme has changed
         @param msg: Message Object
@@ -278,7 +286,7 @@ class GotoLineBar(CommandBarBase):
 
 #-----------------------------------------------------------------------------#
 
-class CommandExecuter(txtentry.CommandEntryBase):
+class CommandExecuter(eclib.CommandEntryBase):
     """Part of the Vi emulation, opens a minibuffer to execute EX commands.
     @note: based on search ctrl so we get the nice roudned edges on wxmac.
 
@@ -290,7 +298,7 @@ class CommandExecuter(txtentry.CommandEntryBase):
 
     def __init__(self, parent, id_, size=wx.DefaultSize):
         """Initializes the CommandExecuter"""
-        txtentry.CommandEntryBase.__init__(self, parent, id_, size=size,
+        eclib.CommandEntryBase.__init__(self, parent, id_, size=size,
                                            style=wx.TE_PROCESS_ENTER|wx.WANTS_CHARS)
 
         # Attributes
@@ -456,7 +464,6 @@ class CommandExecuter(txtentry.CommandEntryBase):
             return
 
         self.CommandPush(cmd_str)
-        self._histidx = -1
         self.GetParent().Hide()
 
     def GetHistCommand(self, pre=True):
@@ -591,7 +598,8 @@ class CommandExecuter(txtentry.CommandEntryBase):
         if len(paths):
             pos = self.GetScreenPosition().Get()
             extent = self.GetTextExtent(cstr)
-            self._popup.SetPosition((pos[0] + extent[0], pos[1] + extent[1] + 7))
+            self._popup.SetPosition((pos[0] + extent[0],
+                                    pos[1] + extent[1] + 7))
             self._popup.SetBestSelection(cmd)
             if not self._popup.IsShown():
                 self._popup.Show()
@@ -716,6 +724,7 @@ class CommandExecuter(txtentry.CommandEntryBase):
         self._AdjustSize()
 
     def UpdateAutoComp(self):
+        """Update the autocomp list for paths that best match current value"""
         self.ListDir()
         val = self.GetValue().split(' ', 1)[-1]
         self._popup.SetBestSelection(val)
@@ -731,7 +740,7 @@ class CommandExecuter(txtentry.CommandEntryBase):
 
 #-----------------------------------------------------------------------------#
 
-class LineCtrl(txtentry.CommandEntryBase):
+class LineCtrl(eclib.CommandEntryBase):
     """A custom int control for providing a go To line control
     for the Command Bar.
 
@@ -742,7 +751,7 @@ class LineCtrl(txtentry.CommandEntryBase):
                         current document.
 
         """
-        txtentry.CommandEntryBase.__init__(self, parent, id_, "", size=size,
+        eclib.CommandEntryBase.__init__(self, parent, id_, "", size=size,
                                            style=wx.TE_PROCESS_ENTER,
                                            validator=util.IntValidator(0, 65535))
 
@@ -787,6 +796,7 @@ class LineCtrl(txtentry.CommandEntryBase):
 # TODO: merge the common parts of these two classes into a single base class
 
 class PopupList(wx.MiniFrame):
+    """Popup window with a listbox in it"""
     def __init__(self, parent, choices=list(), pos=wx.DefaultPosition):
 
         style = wx.FRAME_NO_TASKBAR | wx.FRAME_FLOAT_ON_PARENT
@@ -866,6 +876,7 @@ class PopupList(wx.MiniFrame):
         return self._list.GetStrings()
 
     def GetListCtrl(self):
+        """Get the ListBox control of the popupwindow"""
         return self._list
 
     def GetSelection(self):
@@ -904,6 +915,7 @@ class PopupList(wx.MiniFrame):
         self.__PostEvent()
 
     def OnSize(self, evt):
+        """Resize the listbox"""
         csz = self.GetClientSize()
         csz.SetWidth(csz.x + wx.SystemSettings.GetMetric(wx.SYS_VSCROLL_X))
         self._list.SetSize(csz)
@@ -1014,6 +1026,7 @@ class PopupWinList(wx.PopupWindow):
         return self._list.GetStringSelection()
 
     def OnSize(self, evt):
+        """Resize the list box to the correct size to fit."""
         csz = self.GetClientSize()
         csz.SetWidth(csz.x + wx.SystemSettings.GetMetric(wx.SYS_VSCROLL_X))
         self._list.SetSize(csz)
