@@ -14,8 +14,8 @@ access point for all common variables in the project.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 58981 2009-02-18 05:29:42Z CJP $"
-__revision__ = "$Revision: 58981 $"
+__svnid__ = "$Id: ed_glob.py 59569 2009-03-16 03:40:34Z CJP $"
+__revision__ = "$Revision: 59569 $"
 
 __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
@@ -23,7 +23,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 'ID_REDO', 'ID_CUT',
             'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 'ID_ADD_BM',
             'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 'ID_LINE_BEFORE', 'ID_CUT_LINE',
-            'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE',
+            'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE', 'ID_DELETE_LINE',
             'ID_QUICK_FIND', 'ID_PREF', 'ID_ZOOM_OUT',
             'HOME_PAGE', 'CONTACT_MAIL', 'ID_ZOOM_IN', 'ID_ZOOM_NORMAL',
             'ID_SHOW_EDGE', 'ID_SHOW_EOL', 'ID_SHOW_LN', 'ID_SHOW_WS',
@@ -36,13 +36,13 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER',
             'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 'ID_MACRO_STOP',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
-            'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
+            'ID_DOCUMENTATION', 'ID_COMMAND',
             'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
             'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE', 'ID_SHOW_SB',
             'ID_REVERT_FILE', 'ID_RELOAD_ENC', 'ID_DOCPROP', 'ID_PASTE_AFTER',
             'ID_COLUMN_MODE', 'ID_PANELIST', 'ID_MAXIMIZE_EDITOR', 
             'ID_NEW_WINDOW', 'ID_TOGGLE_FOLD', 'ID_TOGGLE_ALL_FOLDS',
-            'ID_FIND_SELECTED']
+            'ID_SAVE_SESSION', 'ID_LOAD_SESSION']
 
 #---- Project Info ----#
 # The project info was moved to another module so it could be accessed
@@ -98,6 +98,8 @@ ID_REVERT_FILE   = wx.ID_REVERT_TO_SAVED
 ID_RELOAD_ENC    = wx.NewId()
 ID_SAVE_PROFILE  = wx.NewId()
 ID_LOAD_PROFILE  = wx.NewId()
+ID_SAVE_SESSION  = wx.NewId()
+ID_LOAD_SESSION  = wx.NewId()
 ID_PRINT         = wx.ID_PRINT
 ID_PRINT_PRE     = wx.ID_PREVIEW
 ID_PRINT_SU      = wx.NewId()
@@ -120,6 +122,7 @@ ID_DEL_ALL_BM    = wx.NewId()
 ID_LINE_AFTER    = wx.NewId()
 ID_LINE_BEFORE   = wx.NewId()
 ID_CUT_LINE      = wx.NewId()
+ID_DELETE_LINE   = wx.NewId()
 ID_COPY_LINE     = wx.NewId()
 ID_DUP_LINE      = wx.NewId()
 ID_JOIN_LINES    = wx.NewId()
@@ -141,6 +144,7 @@ ID_PREF          = wx.ID_PREFERENCES
 # Prefrence Dlg Ids
 ID_PREF_LANG     = wx.NewId()
 ID_PREF_AALIAS   = wx.NewId()
+ID_PREF_AUTO_RELOAD = wx.NewId()
 ID_PREF_AUTOTRIM = wx.NewId()
 ID_PREF_CHKMOD   = wx.NewId()
 ID_PREF_CHKUPDATE = wx.NewId()
@@ -246,7 +250,6 @@ ID_BACKWARD          = wx.ID_BACKWARD
 ID_BIN_FILE          = ID_COMMAND
 ID_CDROM             = wx.NewId()
 ID_COMMAND_LINE_OPEN = wx.NewId()
-ID_COMMAND_BAR       = wx.NewId()
 ID_COMPUTER          = wx.NewId()
 ID_COPY_PATH         = wx.NewId()
 ID_DELETE            = wx.NewId()
@@ -299,6 +302,7 @@ ID_2_PROF = {
              ID_APP_SPLASH        : 'APPSPLASH',
              ID_AUTOCOMP          : 'AUTO_COMP',
              ID_AUTOINDENT        : 'AUTO_INDENT',
+             ID_PREF_AUTO_RELOAD  : 'AUTO_RELOAD',
              ID_PREF_AUTOTRIM     : 'AUTO_TRIM_WS',
              ID_BRACKETHL         : 'BRACKETHL',
              ID_PREF_CHKMOD       : 'CHECKMOD',
