@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 58981 2009-02-18 05:29:42Z CJP $"
-__revision__ = "$Revision: 58981 $"
+__svnid__ = "$Id: ed_main.py 59569 2009-03-16 03:40:34Z CJP $"
+__revision__ = "$Revision: 59569 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -44,8 +44,7 @@ import generator
 import plugin
 import perspective as viewmgr
 import iface
-import eclib.encdlg as encdlg
-import eclib.auinavi as auinavi
+import eclib
 
 # Function Aliases
 _ = wx.GetTranslation
@@ -59,6 +58,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     @todo: modularize the event handling more (pubsub?)
 
     """
+    PRINTER = None
+
     def __init__(self, parent, id_, wsize, title):
         """Initialiaze the Frame and Event Handlers.
         @param wsize: Windows initial size
@@ -88,6 +89,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Attributes
         self._loaded = False
+        self._last_save = u''
         self.LOG = wx.GetApp().GetLog()
         self._exiting = False
         self._handlers = dict(menu=list(), ui=list())
@@ -116,6 +118,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #---- Pane Navigator ----#
         self._paneNavi = None
 
+        # Printer Setup
+        if MainWindow.PRINTER is None:
+            MainWindow.PRINTER = ed_print.EdPrinter(self)
+
         #---- Setup Toolbar ----#
         self.SetToolBar(ed_toolbar.EdToolBar(self))
         self.GetToolBar().Show(_PGET('TOOLBAR'))
@@ -158,6 +164,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        (ID_RELOAD_ENC, self.OnReloadWithEnc),
                                        (ID_SAVE_PROFILE, self.OnSaveProfile),
                                        (ID_LOAD_PROFILE, self.OnLoadProfile),
+                                       (ID_SAVE_SESSION, self.OnSaveSession),
+                                       (ID_LOAD_SESSION, self.OnLoadSession),
                                        (ID_EXIT, wx.GetApp().OnExit),
                                        (ID_PRINT, self.OnPrint),
                                        (ID_PRINT_PRE, self.OnPrint),
@@ -305,6 +313,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         # Don't needlessly push and pop events if we only have one window open
         if self._loaded and len(app.GetMainWindows()) == 1:
             if active:
+                wx.GetApp().SetTopWindow(self)
                 wx.UpdateUIEvent.SetUpdateInterval(205)
                 wx.UpdateUIEvent.SetMode(wx.UPDATE_UI_PROCESS_SPECIFIED)
                 self.SetExtraStyle(wx.WS_EX_PROCESS_UI_UPDATES)
@@ -316,6 +325,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Add or remove handlers from the event stack
         if active:
+            wx.GetApp().SetTopWindow(self)
             self._loaded = True
 
             # Slow the update interval to reduce overhead
@@ -489,6 +499,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         return self._exiting
 
+    def IsTopWindow(self):
+        """Is this main window 'the' current top window
+        @return: bool
+
+        """
+        return wx.GetApp().GetTopWindow() == self
+
     def LoadFileHistory(self, size):
         """Loads file history from profile
         @return: None
@@ -545,8 +562,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Check if file still exists
         if not os.path.exists(fname):
-            mdlg = wx.MessageDialog(self, _("%s could not be found\nPerhaps "
-                                            "its been moved or deleted") % \
+            mdlg = wx.MessageDialog(self, _("%s could not be found.\nPerhaps "
+                                            "it's been moved or deleted.") % \
                                     fname, _("File Not Found"),
                                     wx.OK | wx.ICON_WARNING)
             mdlg.CenterOnParent()
@@ -603,6 +620,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             if fname != '':
                 fpath = ctrl[1].GetFileName()
                 result = ctrl[1].SaveFile(fpath)
+                self._last_save = fpath
                 if result:
                     self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
                 else:
@@ -613,7 +631,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             else:
                 ret_val = self.OnSaveAs(ID_SAVEAS, ctrl[0], ctrl[1])
                 if ret_val:
-                    self.AddFileToHistory(ctrl[1].GetFileName())
+                    self._last_save = ctrl[1].GetFileName()
+                    self.AddFileToHistory(self._last_save)
 
     def OnSaveAs(self, evt, title=u'', page=None):
         """Save File Using a new/different name
@@ -629,10 +648,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         if title == u'':
             title = os.path.split(ctrl.GetFileName())[1]
 
+        sdir = ctrl.GetFileName()
+        if sdir is None or not len(sdir):
+            sdir = self._last_save
+
         dlg = wx.FileDialog(self, _("Choose a Save Location"),
-                            os.path.dirname(ctrl.GetFileName()),
-                            title.lstrip("*"),
-                            ''.join(syntax.GenFileFilters()),
+                            os.path.dirname(sdir),
+                            title.lstrip(u"*"),
+                            u''.join(syntax.GenFileFilters()),
                             wx.SAVE | wx.OVERWRITE_PROMPT)
 
         if dlg.ShowModal() == wx.ID_OK:
@@ -647,6 +670,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 ctrl.GetDocument().ResetAll()
                 self.PushStatusText(_("ERROR: Failed to save %s") % fname, SB_INFO)
             else:
+                self._last_save = path
                 self.PushStatusText(_("Saved File As: %s") % fname, SB_INFO)
                 self.SetTitle("%s - file://%s" % (fname, ctrl.GetFileName()))
                 self.nb.SetPageText(self.nb.GetSelection(), fname)
@@ -701,6 +725,61 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
+    def OnSaveSession(self, evt):
+        """Save the current session of open files.
+        @todo: Save all windows and what the active tabs are as well
+
+        """
+        if evt.GetId() == ID_SAVE_SESSION:
+            # TODO: set current profile as default
+            dlg = wx.FileDialog(self, _("Where to Save Session?"), \
+                               CONFIG['SESSION_DIR'], u"", \
+                               _("Session") + " (*.session)|*.session",
+                                wx.SAVE | wx.OVERWRITE_PROMPT)
+
+            if dlg.ShowModal() == wx.ID_OK:
+                fname = dlg.GetPath()
+                if fname is None or not len(fname):
+                    return
+
+                if not fname.endswith('.session'):
+                    fname = fname.rstrip(u'.') + u'.session'
+                rval = self.nb.SaveSessionFile(fname)
+                if rval is not None:
+                    wx.MessageBox(rval[1], rval[0], wx.OK|wx.ICON_ERROR)
+                    return
+
+                self.PushStatusText(_("Session Saved as: %s") % fname, SB_INFO)
+                _PSET('LAST_SESSION', fname)
+            dlg.Destroy()
+        else:
+            evt.Skip()
+
+    def OnLoadSession(self, evt):
+        """Load a saved session."""
+        if evt.GetId() == ID_LOAD_SESSION:
+            # TODO: set current file as default
+            dlg = wx.FileDialog(self, _("Load a Session file"),
+                                CONFIG['SESSION_DIR'], u"",
+                                _("Session") + " (*.session)|*.session", wx.OPEN)
+
+            if dlg.ShowModal() == wx.ID_OK:
+                fname = dlg.GetPath()
+                nbook = self.GetNotebook()
+                rval = nbook.LoadSessionFile(fname)
+
+                # Check for an error during load
+                if rval is not None:
+                    wx.MessageBox(rval[1], rval[0], wx.OK|wx.ICON_WARNING)
+                    return
+                
+                self.PushStatusText(_("Loaded Session: %s") % fname, SB_INFO)
+                _PSET('LAST_SESSION', fname)
+
+            dlg.Destroy()
+        else:
+            evt.Skip()
+
     def OnStatus(self, evt):
         """Update status text with messages from other controls
         @param evt: event that called this handler
@@ -724,7 +803,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         e_id = evt.GetId()
-        printer = ed_print.EdPrinter(self, self.nb.GetCurrentCtrl)
+        printer = MainWindow.PRINTER
+        printer.SetStc(self.nb.GetCurrentCtrl())
         printer.SetColourMode(_PGET('PRINT_MODE'))
         if e_id == ID_PRINT:
             printer.Print()
@@ -756,8 +836,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @return: None on destroy, or True on cancel
 
         """
+        # Save session files
+        session = _PGET('LAST_SESSION')
+        if not session or session is None:
+            session = os.path.join(CONFIG['SESSION_DIR'], u"__default.session")
+        _PSET('LAST_SESSION', session)
+        self.nb.SaveSessionFile(session)
+
         # Cleanup Controls
-        _PSET('LAST_SESSION', self.nb.GetFileNames())
         self._exiting = True
         controls = self.nb.GetPageCount()
         self.LOG("[ed_main][evt] OnClose: Number of controls: %d" % controls)
@@ -803,18 +889,20 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.LOG("[ed_main][evt] OnClose: Closing editor at pos=%s size=%s" % \
                  (_PGET('WPOS', 'str'), _PGET('WSIZE', 'str')))
 
-        # Update profile
-        profiler.AddFileHistoryToProfile(self.filehistory)
-        ppath = _PGET('MYPROFILE')
-        profiler.Profile().Write(ppath)
-        self.LOG("[ed_main][info] Saving profile to %s" % ppath)
-
         # Cleanup file history
+        # TODO: Find out why filehistory can be undefined by this point
+        #       sometimes.
         try:
+            profiler.AddFileHistoryToProfile(self.filehistory)
             del self.filehistory
         except AttributeError:
             self.LOG("[ed_main][err] OnClose: Trapped AttributeError OnExit")
 
+        # Update profile
+        ppath = _PGET('MYPROFILE')
+        profiler.Profile().Write(ppath)
+        self.LOG("[ed_main][info] Saving profile to %s" % ppath)
+
         # Post exit notice to all aui panes
         panes = self._mgr.GetAllPanes()
         exit_evt = ed_event.MainWindowExitEvent(ed_event.edEVT_MAINWINDOW_EXIT,
@@ -942,8 +1030,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 win.Raise()
                 return
             dlg = plugdlg.PluginDialog(self, wx.ID_ANY, PROG_NAME + " " \
-                                        + _("Plugin Manager"), \
-                                        size=wx.Size(550, 350))
+                                       + _("Plugin Manager"), \
+                                       size=wx.Size(550, 450))
             dlg.CenterOnParent()
             dlg.Show()
         else:
@@ -988,7 +1076,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                         ID_SELECTALL, ID_UNDO, ID_REDO, ID_CUT, ID_COPY,
                         ID_PASTE, ID_LINE_BEFORE, ID_LINE_AFTER, ID_DUP_LINE,
                         ID_PASTE_AFTER, ID_COLUMN_MODE, ID_TOGGLE_FOLD,
-                        ID_TOGGLE_ALL_FOLDS ]
+                        ID_TOGGLE_ALL_FOLDS, ID_DELETE_LINE ]
 
         # Special handling for common clipboard related actions
         has_focus = self.FindFocus()
@@ -1038,7 +1126,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             ctrl = self.nb.GetCurrentCtrl()
             doc = ctrl.GetDocument()
             cenc = doc.GetEncoding()
-            dlg = encdlg.EncodingDialog(self.GetNotebook(),
+            dlg = eclib.EncodingDialog(self.GetNotebook(),
                                         msg=_("Select an encoding to reload the file with"),
                                         title=_("Reload with Encoding"),
                                         default=cenc)
@@ -1070,7 +1158,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 return
 
             bmp = wx.ArtProvider.GetBitmap(str(ID_NEW_WINDOW), wx.ART_MENU)
-            self._paneNavi = auinavi.AuiPaneNavigator(self, self._mgr, bmp,
+            self._paneNavi = eclib.AuiPaneNavigator(self, self._mgr, bmp,
                                                       _("Aui Pane Navigator"))
             self._paneNavi.SetReturnCode(wx.ID_OK)
             self._paneNavi.ShowModal()
@@ -1117,35 +1205,29 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         e_id = evt.GetId()
         focus = self.FindFocus()
-        ctrl = self.nb.GetCurrentCtrl()
         enable = False
         if e_id == ID_UNDO:
             if hasattr(focus, 'CanUndo'):
                 enable = focus.CanUndo()
             evt.Enable(enable)
         elif e_id == ID_REDO:
-            can_redo = False
             if hasattr(focus, 'CanRedo'):
                 enable = focus.CanRedo()
             evt.Enable(enable)
         elif e_id in (ID_PASTE, ID_PASTE_AFTER):
-            can_paste = False
             if hasattr(focus, 'CanPaste'):
                 enable = focus.CanPaste()
             evt.Enable(enable)
         elif e_id == ID_COPY:
-            can_copy = False
             if hasattr(focus, 'CanCopy'):
                 enable = focus.CanCopy()
             evt.Enable(enable)
         elif e_id == ID_CUT:
-            can_cut = False
             if hasattr(focus, 'CanCut'):
                 enable = focus.CanCut()
             evt.Enable(enable)
         elif e_id == ID_COLUMN_MODE:
             if hasattr(focus, 'IsColumnMode'):
-                enable = focus.IsColumnMode()
                 evt.Enable(True)
             else:
                 evt.Enable(False)
