@@ -14,8 +14,8 @@ for managing keybindings and profiles is also provided by this module.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 58981 2009-02-18 05:29:42Z CJP $"
-__revision__ = "$Revision: 58981 $"
+__svnid__ = "$Id: ed_menu.py 59569 2009-03-16 03:40:34Z CJP $"
+__revision__ = "$Revision: 59569 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -499,6 +499,8 @@ class EdMenuBar(wx.MenuBar):
                         u"..." + EdMenuBar.keybinder.GetBinding(ed_glob.ID_RELOAD_ENC),
                         _("Reload the file with a specified encoding"))
         filemenu.AppendSeparator()
+
+        # Profile
         pmenu = EdMenu()
         pmenu.Append(ed_glob.ID_SAVE_PROFILE, _("Save Profile") + \
                      EdMenuBar.keybinder.GetBinding(ed_glob.ID_SAVE_PROFILE),
@@ -508,6 +510,18 @@ class EdMenuBar(wx.MenuBar):
                      _("Load a Custom Profile"))
         filemenu.AppendSubMenu(pmenu, _("Profile"),
                                _("Load and save custom Profiles"))
+
+        # Sessions
+        smenu = EdMenu()
+        smenu.Append(ed_glob.ID_SAVE_SESSION, _("Save Session") + \
+                     EdMenuBar.keybinder.GetBinding(ed_glob.ID_SAVE_SESSION),
+                     _("Save the current session."))
+        smenu.Append(ed_glob.ID_LOAD_SESSION, _("Load Session") + \
+                     EdMenuBar.keybinder.GetBinding(ed_glob.ID_LOAD_SESSION),
+                     _("Load a saved session."))
+        filemenu.AppendSubMenu(smenu, _("Sessions"),
+                               _("Load and save custom sessions."))
+
         filemenu.AppendSeparator()
         filemenu.Append(ed_glob.ID_PRINT_SU, _("Page Set&up") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_PRINT_SU),
@@ -572,6 +586,9 @@ class EdMenuBar(wx.MenuBar):
         linemenu.Append(ed_glob.ID_CUT_LINE, _("Cut Line") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_CUT_LINE),
                         _("Cut Current Line"))
+        linemenu.Append(ed_glob.ID_DELETE_LINE, _("Delete Line") + \
+                        EdMenuBar.keybinder.GetBinding(ed_glob.ID_DELETE_LINE),
+                        _("Delete the selected line(s)"))
         linemenu.Append(ed_glob.ID_COPY_LINE, _("Copy Line") + \
                         EdMenuBar.keybinder.GetBinding(ed_glob.ID_COPY_LINE),
                         _("Copy Current Line"))
@@ -1002,6 +1019,7 @@ _DEFAULT_BINDING = { # File Menu
                      ed_glob.ID_LINE_AFTER : (u"Ctrl", u"L"),
                      ed_glob.ID_LINE_BEFORE : (u"Ctrl", u"Shift", u"L"),
                      ed_glob.ID_CUT_LINE : (u"Ctrl", u"D"),
+                     ed_glob.ID_DELETE_LINE : (u"Ctrl", u"Shift", "D"),
                      ed_glob.ID_COPY_LINE : (u"Ctrl", u"Y"),
                      ed_glob.ID_DUP_LINE : (u"Ctrl", u"Shift", u"C"),
                      ed_glob.ID_JOIN_LINES : (u"Ctrl", u"J"),
