@@ -15,8 +15,8 @@ notebook.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_tab.py 57706 2009-01-01 21:53:25Z CJP $"
-__revision__ = "$Revision: 57706 $"
+__svnid__ = "$Id: ed_tab.py 58997 2009-02-18 16:00:24Z CJP $"
+__revision__ = "$Revision: 58997 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -43,6 +43,10 @@ class EdTabBase(object):
 
     #---- Methods to override in subclasses ----#
 
+    def DoDeactivateTab(self):
+        """Called when the tab is moved from the foreground to background"""
+        pass
+
     def DoOnIdle(self):
         """Called when the notebook is idle and this instance is the active
         tab.
@@ -90,6 +94,13 @@ class EdTabBase(object):
         """
         return True
 
+    def OnTabMenu(self, evt):
+        """Handle events from this tabs menu
+        @param evt: menu event
+
+        """
+        evt.Skip()
+
     #---- Common Base Methods ----#
 
     def GetTabLabel(self):
