@@ -16,8 +16,8 @@ can be installed as single file instead of dozens of individual image files.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 57365 2008-12-16 02:02:11Z CJP $"
-__revision__ = "$Revision: 57365 $"
+__svnid__ = "$Id: ed_theme.py 58981 2009-02-18 05:29:42Z CJP $"
+__revision__ = "$Revision: 58981 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -198,6 +198,7 @@ class BitmapProvider(plugin.Plugin):
 ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_ADD_BM : u'bmark_add.png',
         ed_glob.ID_ADVANCED : u'advanced.png',
+        ed_glob.ID_BACKWARD : u'backward.png',
         ed_glob.ID_BIN_FILE : u'bin_file.png',
         ed_glob.ID_CDROM  : u'cdrom.png',
         ed_glob.ID_CONTACT : u'mail.png',
@@ -216,11 +217,11 @@ ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_FLOPPY : u'floppy.png',
         ed_glob.ID_FOLDER : u'folder.png',
         ed_glob.ID_FONT   : u'font.png',
+        ed_glob.ID_FORWARD : u'forward.png',
         ed_glob.ID_HARDDISK : u'harddisk.png',
         ed_glob.ID_HOMEPAGE : u'web.png',
         ed_glob.ID_HTML_GEN : u'html_gen.png',
         ed_glob.ID_INDENT : u'indent.png',
-        ed_glob.ID_KWHELPER : u'kw_help.png',
         ed_glob.ID_LOGGER : u'log.png',
         ed_glob.ID_NEW    : u'new.png',
         ed_glob.ID_NEW_WINDOW: u'newwin.png',
