@@ -13,39 +13,50 @@ Provides a dialog for downloading, installing and configuring plugins or Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 57118 2008-12-05 02:03:02Z CJP $"
-__revision__ = "$Revision: 57118 $"
+__cvsid__ = "$Id: plugdlg.py 59902 2009-03-28 16:21:50Z CJP $"
+__revision__ = "$Revision: 59902 $"
 
-#--------------------------------------------------------------------------#
-# Dependancies
-import sys
+#-----------------------------------------------------------------------------#
+# Imports
 import os
+import sys
 import re
 import urllib2
 import wx
 import wx.lib.delayedresult as delayedresult
-import wx.lib.mixins.listctrl as listmix
 
-# Editra Libraries
+# Local Imports
 import ed_glob
-from profiler import Profile_Get, Profile_Set
-import ed_event
 import plugin
+import ed_event
 import util
-import eclib.pstatbar as pstatbar
-import eclib.elistmix as elistmix
+import ed_txt
+from profiler import Profile_Get, Profile_Set
+import eclib
 
-#--------------------------------------------------------------------------#
+#-----------------------------------------------------------------------------#
 # Globals
+
 CONFIG_PG = 0
 DOWNLOAD_PG = 1
 INSTALL_PG = 2
 PY_VER = str(sys.version_info[0]) + str(sys.version_info[1])
 PLUGIN_REPO = "http://editra.org/plugins.php?list=True&py=" + PY_VER
 
+# Panel Display Modes
+MODE_CONFIG = 0
+MODE_ERROR  = 1
+
+# Image list indexes
+IMG_CONFIG   = 0
+IMG_DOWNLOAD = 1
+IMG_INSTALL  = 2
+IMG_ERROR    = 3
+IMG_PLUGIN   = 4
+
 _ = wx.GetTranslation
 
-#--------------------------------------------------------------------------#
+#-----------------------------------------------------------------------------#
 
 def MakeThemeTool(tool_id):
     """Makes a themed bitmap for the tool book of the plugin dialog.
@@ -58,7 +69,7 @@ def MakeThemeTool(tool_id):
     Profile_Set('ICON_SZ', (32, 32))
     base = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
     Profile_Set('ICON_SZ', osize)
-    if not base.IsOk() or base.GetSize() != (32, 32):
+    if not base.IsOk():
         base = wx.ArtProvider.GetBitmap(wx.ART_WARNING,
                                         wx.ART_TOOLBAR,
                                         size=(32, 32))
@@ -75,36 +86,63 @@ def MakeThemeTool(tool_id):
 
     return base
 
-#--------------------------------------------------------------------------#
+#-----------------------------------------------------------------------------#
 
 class PluginDialog(wx.Frame):
     """Defines a Plugin manager Dialog that can be used to download plugins
-    from a defined repository, offers servcies to install plugins that
+    from a defined repository, offers services to install plugins that
     where downloaded with or without the dialog, as well as configure
     already installed plugins. It is instanciated as a standalone window
     when the show method is called so that if downloads are taking along time
     it does not interfere with usage of the editor.
 
     """
-    def __init__(self, parent, fid, title, pos=wx.DefaultPosition,
-                 size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE):
-        """Creates the dialog, does not call Show()"""
-        wx.Frame.__init__(self, parent, fid, title, pos, size, style)
+    def __init__(self, parent, id=wx.ID_ANY, title=u'', size=wx.DefaultSize):
+        wx.Frame.__init__(self, parent, title=title, size=size,
+                              style=wx.DEFAULT_FRAME_STYLE)
         util.SetWindowIcon(self)
 
         # Attributes
-        sizer = wx.BoxSizer(wx.VERTICAL)
-        self.SetStatusBar(pstatbar.ProgressStatusBar(self, style=wx.SB_FLAT))
-        self._nb = PluginPages(self)
+        bstyle = eclib.SEGBOOK_STYLE_NO_DIVIDERS|eclib.SEGBOOK_STYLE_LABELS
+        self._nb = eclib.SegmentBook(self, style=bstyle)
+        self._cfg_pg = ConfigPanel(self._nb, style=wx.BORDER_SUNKEN)
+        self._dl_pg = DownloadPanel(self._nb)
+        self._inst_pg = InstallPanel(self._nb)
+        self._imglst = list()
 
-        # Layout Dialog
+        # Setup
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PACKAGE))
+        bmp = wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_TOOLBAR, (32, 32))
+        self._imglst.append(bmp)
+        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF),
+                                       wx.ART_TOOLBAR, (32, 32))
+        self._imglst.append(bmp)
+        self._nb.SetImageList(self._imglst)
+        self._nb.SetUsePyImageList(True)
+
+        self._nb.AddPage(self._cfg_pg, _("Configure"), img_id=IMG_CONFIG)
+        self._nb.AddPage(self._dl_pg, _("Download"), img_id=IMG_DOWNLOAD)
+        self._nb.AddPage(self._inst_pg, _("Install"), img_id=IMG_INSTALL)
+
+        # Check for plugins with error conditions and if any are found
+        # Add the error page.
+        pmgr = wx.GetApp().GetPluginManager()
+        if len(pmgr.GetIncompatible()):
+            self._nb.AddPage(ConfigPanel(self._nb, style=wx.BORDER_SUNKEN,
+                                         mode=MODE_ERROR),
+                             _("Errors"), img_id=IMG_ERROR)
+
+        # Layout
+        sizer = wx.BoxSizer(wx.VERTICAL)
         sizer.Add(self._nb, 1, wx.EXPAND)
-        self._title = title
         self.SetSizer(sizer)
-        self.SetAutoLayout(True)
-        self.SetMinSize(size)
+        self.SetStatusBar(eclib.ProgressStatusBar(self, style=wx.SB_FLAT))
+        self.SetInitialSize(size)
 
         # Event Handlers
+        self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
 
     def OnClose(self, evt):
@@ -114,10 +152,10 @@ class PluginDialog(wx.Frame):
         @type evt: wx.EVT_CLOSE
 
         """
-        busy = self._nb.IsBusy()
-        if busy:
-            dlg = wx.MessageDialog(self, busy, _("Do you wish to exit?"),
-                                   style = wx.YES_NO | wx.ICON_EXCLAMATION | \
+        if self._dl_pg.IsDownloading():
+            dlg = wx.MessageDialog(self, _("Downloads are incomplete"),
+                                   _("Do you wish to exit?"),
+                                   style=wx.YES_NO|wx.ICON_EXCLAMATION| \
                                            wx.CENTER)
             result = dlg.ShowModal()
             dlg.Destroy()
@@ -147,77 +185,32 @@ class PluginDialog(wx.Frame):
         else:
             self.GetStatusBar().StopBusy()
 
-#--------------------------------------------------------------------------#
-
-class PluginPages(wx.Toolbook):
-    """A notebook that contains three pages. One for downloading,
-    One for installing, and one for configuration.
-
-    """
-    def __init__(self, parent, style=wx.TB_TOP):
-        """Creates the Toolbook"""
-        wx.Toolbook.__init__(self, parent, wx.ID_ANY, style=style)
-
-        # Create Pages
-        self._imglst = wx.ImageList(32, 32)
-        self._imgind = dict()
-        bmp = MakeThemeTool(ed_glob.ID_PREF)
-        self._imgind[CONFIG_PG] = self._imglst.Add(bmp)
-        bmp = MakeThemeTool(ed_glob.ID_WEB)
-        self._imgind[DOWNLOAD_PG] = self._imglst.Add(bmp)
-        bmp = MakeThemeTool(ed_glob.ID_PACKAGE)
-        self._imgind[INSTALL_PG] = self._imglst.Add(bmp)
-        self._config = ConfigPanel(self)
-        self._download = DownloadPanel(self)
-        self._install = InstallPanel(self)
-        self.SetImageList(self._imglst)
-
-        # Add Pages
-        self.AddPage(self._config, _("Configure"),
-                     imageId=self._imgind[CONFIG_PG])
-        self.AddPage(self._download, _("Download"),
-                     imageId=self._imgind[DOWNLOAD_PG])
-        self.AddPage(self._install, _("Install"),
-                     imageId=self._imgind[INSTALL_PG])
-        self.SetSelection(CONFIG_PG)
-
-        # Event handlers
-        self.Bind(wx.EVT_TOOLBOOK_PAGE_CHANGING, self.OnPageChanging)
-
-    def IsBusy(self):
-        """Returns whether any of the operations in the
-        notebook are busy such as downloads or installs.
-        The return will be None if not busy and a message
-        string if it is busy.
-        @return: status of dialog
-        @rtype: string or None
-        """
-        dl_pg = self.GetPage(DOWNLOAD_PG)
-        if dl_pg and dl_pg.IsDownloading():
-            return _("Downloads are incomplete")
-        else:
-            return None
-
     def OnPageChanging(self, evt):
         """Updates pages as they are being changed to.
         @param evt: Event fired that called this handler
-        @type evt: wx.EVT_NOTEBOOK_PAGE_CHANGING
+        @type evt: segmentbk.EVT_SB_PAGE_CHANGING
 
         """
         cur_pg = evt.GetSelection()
-        parent = self.GetParent()
-        parent.SetTitle(parent.GetTitle().split(" | ")[0] + \
-                        " | " + self.GetPageText(cur_pg))
+        self.SetTitle(self.GetTitle().split(" | ")[0] + \
+                      " | " + self._nb.GetPageText(cur_pg))
         if cur_pg == CONFIG_PG:
-            self._config.PopulateCtrl()
-            parent.SetStatusText(_("Changes will take affect once the"
-                                   " program has been restarted"), 0)
+            self._cfg_pg.PopulateCtrl()
+            self.SetStatusText(_("Changes will take affect once the"
+                                 " program has been restarted"), 0)
         elif cur_pg == DOWNLOAD_PG:
-            self._download.UpdateList()
+            self._dl_pg.UpdateList()
         elif cur_pg == INSTALL_PG:
             pass
         else:
-            pass
+            page = self._nb.GetPage(cur_pg)
+            size = page.GetBestSize()
+            s2 = self.GetSize()
+            segbar = self._nb.GetSegmentBar()
+            segsize = segbar.GetBestSize()
+            self.SetClientSize((s2.GetWidth(),
+                                size.GetHeight() + segsize.GetHeight()))
+            self.SetStatusText("", 0)
 
         evt.Skip()
 
@@ -225,22 +218,24 @@ class PluginPages(wx.Toolbook):
 
 class ConfigPanel(wx.Panel):
     """Creates a panel for configuring plugins."""
-    def __init__(self, parent, style=wx.NO_BORDER):
+    def __init__(self, parent, style=wx.SUNKEN_BORDER, mode=MODE_CONFIG):
         """Build config panel"""
         wx.Panel.__init__(self, parent, style=style)
 
         # Attrtibutes
-        self._list = PluginListCtrl(self)
+        self._mode = mode
+        self._list = eclib.PanelBox(self)
 
         # Layout Panel
         sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.Add(wx.StaticText(self, wx.ID_ANY,
-                   _("To enable a plugin check the box next to its label")),
-                   0, wx.ALIGN_CENTER_HORIZONTAL)
-        sizer.Add((10, 10))
         sizer.Add(self._list, 1, wx.EXPAND)
         self.SetSizer(sizer)
 
+        if self._mode == MODE_CONFIG:
+            self.PopulateCtrl()
+        else:
+            self.PopulateErrors()
+
         # Event handlers
         self.Bind(ed_event.EVT_NOTIFY, self.OnNotify)
 
@@ -254,24 +249,11 @@ class ConfigPanel(wx.Panel):
 
         """
         identifer = None
-        if self.HasItem(name):
-            item_id = self._list.FindItem(0, name)
-            ver = self._list.GetItem(item_id, self._list.VERSION_COL)
-            identifer = (name, ver.GetText())
+        for item in self._list.GetItems():
+            if item.GetPluginName().lower() == name.lower():
+                identifer = (name, item.GetVersionString())
         return identifer
 
-    def HasItem(self, name):
-        """Checks if a given named plugin is the list of this panel.
-        @param name: name of item to look for
-        @type name: string
-        @return: whether item is in list or not
-        @rtype: bool
-        """
-        if self._list.FindItem(0, name) >= 0:
-            return True
-        else:
-            return False
-
     def OnNotify(self, evt):
         """Handles the notification events that are
         posted from the list control.
@@ -279,13 +261,29 @@ class ConfigPanel(wx.Panel):
         @type evt: ed_event.NotificationEvent
 
         """
-        index = evt.GetId()
-        pin = self._list.GetItemText(index)
-        pmgr = wx.GetApp().GetPluginManager()
-        if evt.GetValue():
-            pmgr.EnablePlugin(pin)
+        e_id = evt.GetId()
+        if e_id == ed_glob.ID_PREF:
+            # TODO: check for an open existing instance of this config objects
+            #       page.
+            cfg_obj = evt.GetValue()
+            parent = self.GetParent() # SegmentBook
+
+            bmp = cfg_obj.GetBitmap()
+            if bmp.IsNull():
+                idx = IMG_PLUGIN
+            else:
+                imglst = parent.GetImageList()
+                imglst.append(bmp)
+                idx = len(imgst) - 1
+
+            label = cfg_obj.GetLabel()
+            panel = cfg_obj.GetConfigPanel(parent)
+            parent.AddPage(panel, label, True, idx)
+            parent.SetSegmentCanClose(parent.GetPageCount() - 1, True)
         else:
-            pmgr.DisablePlugin(pin)
+            enable, pname = evt.GetValue()
+            pmgr = wx.GetApp().GetPluginManager()
+            pmgr.EnablePlugin(pname, enable)
 
     def PopulateCtrl(self):
         """Populates the list of plugins and sets the
@@ -302,37 +300,74 @@ class ConfigPanel(wx.Panel):
         if self._list.GetItemCount():
             self._list.DeleteAllItems()
 
-        p_mgr = wx.GetApp().GetPluginManager()
         p_mgr.ReInit()
-        for item in p_mgr.GetConfig():
+        config = p_mgr.GetConfig()
+        keys = sorted([ ed_txt.DecodeString(name)
+                        for name in config.keys() ],
+                      key=unicode.lower)
+        for item in keys:
+            val = config[item]
             self._list.Freeze()
             mod = sys.modules.get(item)
             pin = PluginData()
             pin.SetName(item)
-            pin.SetDescription(getattr(mod, '__doc__',
-                                       _("No Description Available")))
+            desc = getattr(mod, '__doc__', _("No Description Available"))
+            pin.SetDescription(desc.strip())
             pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
             pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
 
-            self._list.InsertPluginItem(pin)
+            pbi = PBPluginItem(self._list, mod, None, item, pin.GetVersion(),
+                               pin.GetDescription(), pin.GetAuthor())
+
+            pbi.SetChecked(val)
+            self._list.AppendItem(pbi)
             self._list.Thaw()
 
-        # Check Enabled Items
-        for item in p_mgr.GetConfig():
-            ind = self._list.FindItem(0, item)
-            self._list.CheckItem(ind, p_mgr.GetConfig()[item])
+        self._list.SendSizeEvent()
+        return self._list.GetItemCount()
 
+    def PopulateErrors(self):
+        """Populates the list of plugins and sets the
+        values of their states. Any successive calls to
+        this function will clear the list and Repopulate it
+        with current config values. Returns the number of
+        items populated to the list
+        @postcondition: list is popluated with all plugins that are
+                        currently loaded and sets the checkmarks accordingly
+        @return: number of items added to list
+
+        """
+        p_mgr = wx.GetApp().GetPluginManager()
         if self._list.GetItemCount():
-            self._list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(1, self.GetTextExtent("0" * 35)[0])
-            self._list.SetColumnWidth(2, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(3, wx.LIST_AUTOSIZE_USEHEADER)
-            self._list.SendSizeEvent()
+            self._list.DeleteAllItems()
+
+        p_mgr.ReInit()
+        errors = p_mgr.GetIncompatible()
+        keys = sorted([ ed_txt.DecodeString(name)
+                        for name in errors.keys() ],
+                      key=unicode.lower)
+        bmp = wx.ArtProvider.GetBitmap(wx.ART_ERROR, wx.ART_TOOLBAR, (32, 32))
+        msg = _("This plugin requires a newer version of Editra.")
+        for item in keys:
+            val = errors[item]
+            self._list.Freeze()
+            mod = sys.modules.get(val)
+            pin = PluginData()
+            pin.SetName(item)
+            pin.SetAuthor(getattr(mod, '__author__', _("Unknown")))
+            pin.SetVersion(str(getattr(mod, '__version__', _("Unknown"))))
+            pbi = PluginErrorItem(self._list, bmp, item, pin.GetVersion(),
+                                  msg, pin.GetAuthor())
+
+            self._list.AppendItem(pbi)
+            self._list.Thaw()
+
+        self._list.SendSizeEvent()
         return self._list.GetItemCount()
 
 #-----------------------------------------------------------------------------#
 
-class DownloadPanel(wx.Panel):
+class DownloadPanel(eclib.ControlBox):
     """Creates a panel with controls for downloading plugins."""
     ID_DOWNLOAD = wx.NewId()
     EGG_PATTERN = re.compile(r"(?P<name>[^-]+)"
@@ -342,30 +377,24 @@ class DownloadPanel(wx.Panel):
 
     def __init__(self, parent, style=wx.NO_BORDER):
         """Initializes the panel"""
-        wx.Panel.__init__(self, parent, style=style)
+        eclib.ControlBox.__init__(self, parent, style=style)
 
         # Attributes
         self._p_list = dict()           # list of available plugins/meta
         self._dl_list = dict()          # List of download urls
         self._eggcount = 0              # Number of plugins to download
         self._eggbasket = dict()        # Basket of downloaded eggs
-        self._list = PluginListCtrl(self)
-        self._downlb = wx.Button(self, self.ID_DOWNLOAD, _("Download"))
-        self._downlb.Disable()
+        self._list = eclib.PanelBox(self)
 
         # Layout Panel
-        sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.Add(wx.StaticText(self, wx.ID_ANY,
-                  _("Select the desired plugins and then Click Download")),
-                  0, wx.ALIGN_CENTER)
-        sizer.Add(self._list, 1, wx.EXPAND)
-        sizer.Add((5, 5))
-        bsizer = wx.BoxSizer(wx.HORIZONTAL)
-        bsizer.Add(self._downlb, 0, wx.ALIGN_RIGHT)
-        bsizer.Add((5, 5))
-        sizer.Add(bsizer, 0, wx.ALIGN_RIGHT)
-        sizer.Add((5, 5))
-        self.SetSizer(sizer)
+        self.CreateControlBar(wx.BOTTOM)
+        cbar = self.GetControlBar(wx.BOTTOM)
+        cbar.SetVMargin(1, 2)
+        cbar.AddStretchSpacer()
+        self._downlb = wx.Button(cbar, DownloadPanel.ID_DOWNLOAD, _("Download"))
+        self._downlb.Disable()
+        cbar.AddControl(self._downlb, wx.ALIGN_RIGHT)
+        self.SetWindow(self._list)
 
         # Event Handlers
         self.Bind(wx.EVT_BUTTON, self.OnButton)
@@ -442,10 +471,10 @@ class DownloadPanel(wx.Panel):
                            'url' : tmpdat.SetUrl}
                 funct = set_map.get(tmp[0].lower(), None)
                 if funct:
-                    funct(tmp[1].strip())
+                    funct(ed_txt.DecodeString(tmp[1].strip()))
 
             if tmpdat.GetName() != u'':
-                p_list[tmpdat.GetName()] = tmpdat
+                p_list[ed_txt.DecodeString(tmpdat.GetName())] = tmpdat
 
         # Remove items that have already been installed
         config_pg = self.GetParent().GetPage(CONFIG_PG)
@@ -511,10 +540,10 @@ class DownloadPanel(wx.Panel):
 
         """
         index = evt.GetId()
-        flag = evt.GetValue()
-        pin = self._list.GetItemText(index)
-        self._dl_list[pin] = flag
-        if flag:
+        enable, pin = evt.GetValue()
+        self._dl_list[pin] = enable
+
+        if enable:
             self._downlb.Enable()
         else:
             for item in self._dl_list:
@@ -538,17 +567,17 @@ class DownloadPanel(wx.Panel):
         if self._list.GetItemCount():
             self._list.DeleteAllItems()
 
-        for item in self._p_list:
-            self._list.Freeze()
-            self._list.InsertPluginItem(self._p_list[item])
-            self._list.Thaw()
+        pins = sorted([ name for name in self._p_list.keys() ], key=unicode.lower)
+        self.Freeze()
+        for item in pins:
+            data = self._p_list[item]
+            pbi = PBDownloadItem(self._list, None, data.GetName(),
+                                 data.GetVersion(), data.GetDescription(),
+                                 data.GetAuthor())
+            self._list.AppendItem(pbi)
 
-        if self._list.GetItemCount():
-            self._list.SetColumnWidth(0, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(1, self.GetTextExtent("0" * 35)[0])
-            self._list.SetColumnWidth(2, wx.LIST_AUTOSIZE)
-            self._list.SetColumnWidth(3, wx.LIST_AUTOSIZE)
-            self._list.SendSizeEvent()
+        self.Thaw()
+        self._list.SendSizeEvent()
         return self._list.GetItemCount()
 
     def RemoveDownloadedItem(self, item):
@@ -643,7 +672,7 @@ def _DownloadPlugin(*args):
 
 #-----------------------------------------------------------------------------#
 
-class InstallPanel(wx.Panel):
+class InstallPanel(eclib.ControlBox):
     """Creates a panel for installing plugins."""
     ID_INSTALL = wx.NewId()
     ID_USER = wx.NewId()
@@ -652,26 +681,28 @@ class InstallPanel(wx.Panel):
 
     def __init__(self, parent, style=wx.NO_BORDER):
         """Initializes the panel"""
-        wx.Panel.__init__(self, parent, style=style)
+        eclib.ControlBox.__init__(self, parent, style=style)
 
         # Attributes
-        lbl = wx.StaticText(self, wx.ID_ANY,
-                            _("Click on Install to install the plugins "
-                              "in the list"))
+        self.CreateControlBar(wx.BOTTOM)
         toolt = wx.ToolTip(_("To add a new item drag and drop the plugin file "
                              "into the list.\n\nTo remove an item select it "
                              "and hit Delete or Backspace."))
-        self._install = wx.ListBox(self, wx.ID_ANY, style=wx.LB_SORT)
+        self._install = wx.ListBox(self, wx.ID_ANY,
+                                   style=wx.LB_SORT|wx.BORDER_NONE)
         self._install.SetToolTip(toolt)
         self._install.SetDropTarget(util.DropTargetFT(self._install,
                                                       None, self.OnDrop))
-        self._instb = wx.Button(self, self.ID_INSTALL, _("Install"))
+
+        bbar = self.GetControlBar(wx.BOTTOM)
+        bbar.SetVMargin(1, 2)
+        self._instb = wx.Button(bbar, self.ID_INSTALL, _("Install"))
         self._instb.Disable()
-        self._usercb = wx.CheckBox(self, self.ID_USER, _("User Directory"))
+        self._usercb = wx.CheckBox(bbar, self.ID_USER, _("User Directory"))
         self._usercb.SetValue(True)
         toolt = wx.ToolTip(_("Install the plugins only for the current user"))
         self._usercb.SetToolTip(toolt)
-        self._syscb = wx.CheckBox(self, self.ID_SYS, _("System Directory"))
+        self._syscb = wx.CheckBox(bbar, self.ID_SYS, _("System Directory"))
         toolt = wx.ToolTip(_("Install the plugins for all users\n"
                              " **requires administrative privileges**"))
         self._syscb.SetToolTip(toolt)
@@ -679,19 +710,11 @@ class InstallPanel(wx.Panel):
             self._syscb.Disable()
 
         # Layout Panel
-        sizer = wx.BoxSizer(wx.VERTICAL)
-        sizer.AddMany([(lbl, 0, wx.ALIGN_CENTER),
-                       (self._install, 1, wx.EXPAND),
-                       ((5, 5))])
-        bsizer = wx.BoxSizer(wx.HORIZONTAL)
-        bsizer.AddMany([((5, 5)), (self._usercb, 0, wx.ALIGN_LEFT),
-                        ((5, 5)), (self._syscb, 0, wx.ALIGN_LEFT)])
-        bsizer.AddStretchSpacer()
-        bsizer.Add(self._instb, 0, wx.ALIGN_RIGHT)
-        bsizer.Add((5, 5))
-        sizer.Add(bsizer, 0, wx.EXPAND)
-        sizer.Add((5, 5))
-        self.SetSizer(sizer)
+        self.SetWindow(self._install)
+        bbar.AddControl(self._usercb)
+        bbar.AddControl(self._syscb)
+        bbar.AddStretchSpacer()
+        bbar.AddControl(self._instb, wx.ALIGN_RIGHT)
         self.SendSizeEvent()
 
         # Event Handlers
@@ -845,88 +868,208 @@ class InstallPanel(wx.Panel):
 
         evt.Skip()
 
-#--------------------------------------------------------------------------#
+#-----------------------------------------------------------------------------#
 
-class PluginListCtrl(wx.ListCtrl,
-                     listmix.ListCtrlAutoWidthMixin,
-                     listmix.CheckListCtrlMixin,
-                     elistmix.ListRowHighlighter):
-    """Creates a list control for displaying plugins and configuring them."""
-    PLUGIN_COL   = 0
-    DESCRIPT_COL = 1
-    AUTHOR_COL   = 2
-    VERSION_COL  = 3
-
-    def __init__(self, parent):
-        """Initializes the Profile List Control
-        @param parent: parent window of this control
+class PBPluginItem(eclib.PanelBoxItemBase):
+    """PanelBox Item to display configuration information about a plugin."""
+    def __init__(self, parent, mod, bmp=None,
+                 title=u'Plugin Name', version=u'0.0',
+                 desc=u'Description', auth='John Doe',
+                 enabled=False):
+        """Create the PanelBoxItem
+        @param parent: L{PanelBox}
 
         """
-        wx.ListCtrl.__init__(self, parent, wx.ID_ANY,
-                             wx.DefaultPosition, wx.DefaultSize,
-                             style=wx.LC_REPORT | wx.LC_VRULES)
-        elistmix.ListRowHighlighter.__init__(self)
+        eclib.PanelBoxItemBase.__init__(self, parent)
 
-        self.InsertColumn(self.PLUGIN_COL, _("Plugin"))
-        self.InsertColumn(self.DESCRIPT_COL, _("Description"))
-        self.InsertColumn(self.AUTHOR_COL, _("Author"))
-        self.InsertColumn(self.VERSION_COL, _("Version"))
+        # Attributes
+        self._module = mod
+        self._bmp = bmp
+        self._title = wx.StaticText(self, label=title)
+        self._version = wx.StaticText(self, label=version)
+        self._desc = wx.StaticText(self, label=desc)
+        self._auth = wx.StaticText(self, label=_("Author: %s") % auth)
+        self._enabled = wx.CheckBox(self, label=_("Enable"))
+        self._enabled.SetValue(enabled)
+        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF), wx.ART_MENU)
+        self._config = eclib.PlateButton(self,
+                                         label=_("Configure"), bmp=bmp,
+                                         style=eclib.PB_STYLE_NOBG)
+        self._config.Enable(enabled)
 
-        listmix.ListCtrlAutoWidthMixin.__init__(self)
-        listmix.CheckListCtrlMixin.__init__(self)
+        # Setup
+        if not hasattr(mod, 'GetConfigObject'):
+            self._config.Hide()
+        font = self._title.GetFont()
+        font.SetWeight(wx.FONTWEIGHT_BOLD)
+        self._title.SetFont(font)
+        self._version.SetFont(font)
 
-    def GetItemValues(self):
-        """Returns a dictionary of item names mapped to check values,
-        where the item name is the item at column zero and the
-        dictionary contains all entries in the list.
-        @return: mapping of items to check falues
-        @rtype: dict string->bool
+        if wx.Platform == '__WXMAC__':
+            self._desc.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+            self._auth.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+            self._enabled.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+            self._config.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+
+        # Layout
+        self.__DoLayout()
+
+        # Event Handlers
+        self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
+        self.Bind(wx.EVT_BUTTON, self.OnButton)
+
+    def __DoLayout(self):
+        """Layout the panel"""
+        vsizer = wx.BoxSizer(wx.VERTICAL)
+        hsizer = wx.BoxSizer(wx.HORIZONTAL)
+
+        # Left side Bitmap and Checkbox
+        hsizer.Add((5, 5), 0)
+        if self._bmp is not None:
+            self._bmp = wx.StaticBitmap(self, bitmap=self._bmp)
+            hsizer.Add(self._bmp, 0, wx.ALIGN_CENTER_VERTICAL)
+
+        # Central area main content
+        csizer = wx.BoxSizer(wx.VERTICAL)
+        tsizer = wx.BoxSizer(wx.HORIZONTAL)
+        tsizer.AddMany([(self._title, 0), ((20, -1), 1, wx.EXPAND),
+                        (self._version, 0, wx.ALIGN_RIGHT)])
+
+        bsizer = wx.BoxSizer(wx.HORIZONTAL)
+        bsizer.AddMany([(self._auth, 0), ((20, -1), 1, wx.EXPAND),
+                        (self._enabled, 0, wx.ALIGN_CENTER_VERTICAL),
+                        ((5, 5), 0),
+                        (self._config, 0, wx.ALIGN_CENTER_VERTICAL)])
+        csizer.AddMany([(tsizer, 1, wx.EXPAND), ((3, 3), 0),
+                        (self._desc, 0), ((3, 3), 0),
+                        (bsizer, 0, wx.EXPAND)])
+
+        # Finish Layout
+        hsizer.AddMany([((5, 5), 0), (csizer, 1, wx.EXPAND), ((5, 5), 0)])
+        vsizer.AddMany([((4, 4), 0), (hsizer, 0, wx.EXPAND), ((4, 4), 0)])
+        self.SetSizer(vsizer)
+        self.SetAutoLayout(True)
+
+    def GetPluginName(self):
+        """Get the name of the plugin
+        @return: string
 
         """
-        item_vals = dict()
-        for item in range(self.GetItemCount()):
-            pin = self.GetItemText(item)
-            item_vals[pin] = self.IsChecked(item)
-        return item_vals
+        return self._title.GetLabel()
 
-    def OnCheckItem(self, index, flag):
-        """Sends a custom notification event to the lists parent
-        so that it can handle the check event if it needs to.
-        @postcondition: checkbox is checked/unchecked and parent is notified
+    def GetVersionString(self):
+        """Get the version of the plugin
+        @return: string
 
         """
-        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY,
-                                         index, flag, self)
-        wx.PostEvent(self.GetParent(), evt)
-        listmix.CheckListCtrlMixin.OnCheckItem(self, index, flag)
+        return self._version.GetLabel()
 
-    def InsertPluginItem(self, pi_data, check=False):
-        """Does a smart add to the list that will insert the given
-        a PluginData item alphabetically into the table based on
-        the name value.
-        @param pi_data: PluginData object
-        @keyword check: Should the checkbox be checked
+    def OnButton(self, evt):
+        """Handle when the configuration button is hit."""
+        if self._module is not None:
+            cfg_obj = self._module.GetConfigObject()
+            event = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY,
+                                               ed_glob.ID_PREF, cfg_obj)
+            wx.PostEvent(self.GetParent(), event)
+
+    def OnCheck(self, evt):
+        """Notify container of changes to state of plugin"""
+        enabled = self._enabled.GetValue()
+        self._config.Enable(enabled)
+        pname = self._title.GetLabel()
+        event = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY, self.GetId(),
+                                           (enabled, pname), self)
+        wx.PostEvent(self.GetParent(), event)
+
+    def SetChecked(self, check=True):
+        """Set the checkbox
+        @param check: bool
 
         """
-        pname = pi_data.GetName()
-        for item in xrange(self.GetItemCount()):
-            if pname < self.GetItemText(item):
-                self.InsertStringItem(item, pi_data.GetName().strip())
-                self.SetStringItem(item, 1, pi_data.GetDescription().strip())
-                self.SetStringItem(item, 2, re.sub(r"\<+.*\>", '',
-                                                   pi_data.GetAuthor().strip()))
-                self.SetStringItem(item, 3, pi_data.GetVersion().strip())
-                self.CheckItem(item, check)
-                break
-        else:
-            self.Append((pi_data.GetName().strip(),
-                         pi_data.GetDescription().strip(),
-                         re.sub(r"\<+.*\>", '', pi_data.GetAuthor().strip()),
-                         pi_data.GetVersion().strip()))
-
-            self.CheckItem(self.GetItemCount()-1, check)
+        self._enabled.SetValue(check)
+        self._config.Enable(check)
 
 #-----------------------------------------------------------------------------#
+
+class PBDownloadItem(PBPluginItem):
+    """PanelBox Item to display download information about a plugin."""
+    def __init__(self, parent, bmp=None, title=u'Plugin Name', version=u'0.0',
+                 desc=u'Description', auth='John Doe'):
+        """Create the PanelBoxItem
+        @param parent: L{PanelBox}
+
+        """
+        PBPluginItem.__init__(self, parent, None, bmp=bmp, title=title,
+                              version=version, desc=desc, auth=auth)
+
+        # Setup
+        self._enabled.SetLabel(_("Download"))
+        self.Layout()
+
+#-----------------------------------------------------------------------------#
+
+class PluginErrorItem(eclib.PanelBoxItemBase):
+    """PanelBox Item to display configuration information about a plugin."""
+    def __init__(self, parent, bmp,
+                 title=u'Plugin Name', version=u'0.0',
+                 msg=u'Description', auth='John Doe'):
+        """Create the PanelBoxItem
+        @param parent: L{PanelBox}
+
+        """
+        eclib.PanelBoxItemBase.__init__(self, parent)
+
+        # Attributes
+        self._bmp = bmp
+        self._title = wx.StaticText(self, label=title)
+        self._version = wx.StaticText(self, label=version)
+        self._msg = wx.StaticText(self, label=msg)
+        self._auth = wx.StaticText(self, label=_("Author: %s") % auth)
+
+        # Setup
+        font = self._title.GetFont()
+        font.SetWeight(wx.FONTWEIGHT_BOLD)
+        self._title.SetFont(font)
+        self._version.SetFont(font)
+
+        if wx.Platform == '__WXMAC__':
+            self._msg.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+            self._auth.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
+
+        # Layout
+        self.__DoLayout()
+
+    def __DoLayout(self):
+        """Layout the panel"""
+        vsizer = wx.BoxSizer(wx.VERTICAL)
+        hsizer = wx.BoxSizer(wx.HORIZONTAL)
+
+        # Left side Bitmap and Checkbox
+        hsizer.Add((5, 5), 0)
+        if self._bmp is not None:
+            self._bmp = wx.StaticBitmap(self, bitmap=self._bmp)
+            hsizer.Add(self._bmp, 0, wx.ALIGN_CENTER_VERTICAL)
+
+        # Central area main content
+        csizer = wx.BoxSizer(wx.VERTICAL)
+        tsizer = wx.BoxSizer(wx.HORIZONTAL)
+        tsizer.AddMany([(self._title, 0), ((20, -1), 1, wx.EXPAND),
+                        (self._version, 0, wx.ALIGN_RIGHT)])
+
+        bsizer = wx.BoxSizer(wx.HORIZONTAL)
+        bsizer.AddMany([(self._auth, 0)])
+        csizer.AddMany([(tsizer, 1, wx.EXPAND), ((3, 3), 0),
+                        (self._msg, 0), ((3, 3), 0),
+                        (bsizer, 0, wx.EXPAND)])
+
+        # Finish Layout
+        hsizer.AddMany([((5, 5), 0), (csizer, 1, wx.EXPAND), ((5, 5), 0)])
+        vsizer.AddMany([((4, 4), 0), (hsizer, 0, wx.EXPAND), ((4, 4), 0)])
+        self.SetSizer(vsizer)
+        self.SetAutoLayout(True)
+
+#-----------------------------------------------------------------------------#
+
 class PluginData(plugin.PluginData):
     """Plugin Metadata storage class used to store data
     about plugins and where to download them from
@@ -961,3 +1104,6 @@ class PluginData(plugin.PluginData):
             except (TypeError, ValueError):
                 url = u''
         self._url = url
+
+#-----------------------------------------------------------------------------#
+
