@@ -16,8 +16,8 @@ and setting of the program by setting values in the Profile.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 57676 2008-12-30 20:40:41Z CJP $"
-__revision__ = "$Revision: 57676 $"
+__svnid__ = "$Id: prefdlg.py 59324 2009-03-04 22:44:44Z CJP $"
+__revision__ = "$Revision: 59324 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -35,13 +35,11 @@ from profiler import Profile_Get, Profile_Set
 import ed_i18n
 import ed_event
 import ed_crypt
-import ed_stc
 import updater
 import util
 import syntax.syntax as syntax
 import ed_msg
-import eclib.elistmix as elistmix
-import eclib.ecpickers as ecpickers
+import eclib
 
 #----------------------------------------------------------------------------#
 # Globals
@@ -51,21 +49,7 @@ ID_UPDATE_MSG   = wx.NewId()
 
 _ = wx.GetTranslation
 #----------------------------------------------------------------------------#
-# Class Globals
-#from extern.embeddedimage import PyEmbeddedImage
-
-#ButtonBackground = PyEmbeddedImage(
-#    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAABHNCSVQICAgIfAhkiAAAAfhJ"
-#    "REFUWIXtlz9uGkEUh7/ZWbDdEAWH0ltRYCKRigNQxhFS3EUuUjlGspQLODfIAVxEkVPFzgmc"
-#    "LhegCoolupWQ6GIcWIvE7DwmBX9iwGBiMG74SVvM6M37ffPeaEarGFQceJbJZA611inmKBEp"
-#    "l0qlfeA7UOvNq2sxu6lUKpfNZne2nm+x/mR9nv6c/zzn9OspxWLxuFwuvwakB+BEIpE3hb3C"
-#    "+2QyGfM8b67Gw6pUKhy8O/jQbDb3AVFAbvvl9rd8Pn+vxtdVrVY5+nR07Pv+W3djw9vzPI8g"
-#    "uATsQgBisUdsbqZ3fN//6EZc91UikSAIGrcutNZirUUphVLq1vhJeppOc3b249A1xlD/VZ9s"
-#    "3K2MYjbTkbxtm3KNGBpT7H58FrgrlxGDKyI0GsHdAWaQiNBpQX2wBRM3ZKcJmry0J2MMrhjh"
-#    "MnigChjBDY2hVrtAaz3zyZ5W1lpEhNAYFN3KxB/HiUai/SCtNdHoylwMW60rROTfOGxRu+g8"
-#    "B32AYWmtWYmuDswppVhbXcNxnJH4tm0ThiHGhNihjFetPwMAAznHAYyTqyNA50IaosNaS7t9"
-#    "s9E4/TfAvDVayyXAEmAJsARYAixWLxzgywMC/AbI0XmQFv19pvMvigMUgPoCzevA7nA5CgsE"
-#    "KNzUD6fbjpN7ND7pevQP/18X4iAGbqux9wAAAABJRU5ErkJggg==")
+# Utility
 
 def MakeThemeTool(tool_id):
     """Makes a themed bitmap for the tool book of the pref dialog.
@@ -81,6 +65,22 @@ def MakeThemeTool(tool_id):
 
 #----------------------------------------------------------------------------#
 
+class PreferencesPanelBase(object):
+    def __init__(self):
+        object.__init__(self)
+
+        # Attributes
+        self._layout_done = False
+
+    def DoSelected(self):
+        """Handle initial selection to create controls"""
+        if not self._layout_done:
+            self._layout_done = True
+            self._DoLayout()
+            self.SetAutoLayout(True)
+
+#----------------------------------------------------------------------------#
+
 class PreferencesDialog(wx.Frame):
     """Preference dialog for configuring the editor
     @summary: Provides an interface into configuring profile settings
@@ -145,7 +145,7 @@ class PreferencesDialog(wx.Frame):
 
 #-----------------------------------------------------------------------------#
 
-class PrefTools(wx.Toolbook):
+class PrefTools(eclib.SegmentBook):
     """Main sections of the configuration pages
     @note: implements the top level book control for the prefdlg
     @todo: when using BK_BUTTONBAR style so that the icons have text
@@ -159,7 +159,7 @@ class PrefTools(wx.Toolbook):
     UPDATE_PG  = 3
     ADV_PG     = 4
 
-    def __init__(self, parent, tbid=wx.ID_ANY, style=wx.BK_BUTTONBAR):
+    def __init__(self, parent):
         """Initializes the main book control of the preferences dialog
         @summary: Creates the top level notebook control for the prefdlg
                   a toolbar is used for changing pages.
@@ -170,31 +170,41 @@ class PrefTools(wx.Toolbook):
                changed the toolbook icons cannont be updated instantly.
 
         """
-        wx.Toolbook.__init__(self, parent, tbid, style=style)
+        eclib.SegmentBook.__init__(self, parent, wx.ID_ANY,
+                                       style=eclib.SEGBOOK_STYLE_LABELS|\
+                                             eclib.SEGBOOK_STYLE_NO_DIVIDERS)
 
         # Attributes
-        self._imglst = wx.ImageList(32, 32)
-        self._imglst.Add(MakeThemeTool(ed_glob.ID_PREF))
-        self._imglst.Add(MakeThemeTool(ed_glob.ID_THEME))
-        self._imglst.Add(MakeThemeTool(ed_glob.ID_DOCPROP))
-        self._imglst.Add(MakeThemeTool(ed_glob.ID_WEB))
-        self._imglst.Add(MakeThemeTool(ed_glob.ID_ADVANCED))
+        self._imglst = list()
+        self._imglst.append(MakeThemeTool(ed_glob.ID_PREF))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_THEME))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_DOCPROP))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_WEB))
+        self._imglst.append(MakeThemeTool(ed_glob.ID_ADVANCED))
         self.SetImageList(self._imglst)
+        self.SetUsePyImageList(True)
 
         self.AddPage(GeneralPanel(self), _("General"),
-                     imageId=self.GENERAL_PG)
+                     img_id=self.GENERAL_PG)
         self.AddPage(AppearancePanel(self), _("Appearance"),
-                     imageId=self.APPEAR_PG)
+                     img_id=self.APPEAR_PG)
         self.AddPage(DocumentPanel(self), _("Document"),
-                     imageId=self.DOC_PG)
+                     img_id=self.DOC_PG)
         self.AddPage(NetworkPanel(self), _("Network"),
-                     imageId=self.UPDATE_PG)
+                     img_id=self.UPDATE_PG)
         self.AddPage(AdvancedPanel(self), _("Advanced"),
-                     imageId=self.ADV_PG)
+                     img_id=self.ADV_PG)
 
         # Event Handlers
-        self.Bind(wx.EVT_TOOLBOOK_PAGE_CHANGED, self.OnPageChanged)
-        self.Bind(wx.EVT_PAINT, self.OnPaint)
+        self.Bind(eclib.EVT_SB_PAGE_CHANGED, self.OnPageChanged)
+        self.Bind(eclib.EVT_SB_PAGE_CHANGING, self.OnPageChanging)
+
+    def OnPageChanging(self, evt):
+        sel = evt.GetSelection()
+        page = self.GetPage(sel)
+        if hasattr(page, 'DoSelected'):
+            page.DoSelected()
+        evt.Skip()
 
     def OnPageChanged(self, evt=None):
         """Resizes the dialog based on the pages size
@@ -206,68 +216,36 @@ class PrefTools(wx.Toolbook):
         page.SetInitialSize()
         parent = self.GetParent()
         psz = page.GetSize()
-        tbh = self.GetToolBar().GetSize().GetHeight()
+        width = psz.GetWidth()
 
-        # Make sure not to resize the width less than the size needed to show
-        # all the books icons.
-        tbw = self.GetToolBar().GetBestSize().GetWidth()
-        if psz.GetWidth() >= tbw:
-            width = psz.GetWidth()
-        else:
-            width = tbw
+        cbar = self.GetControlBar(wx.TOP)
+        tbsz = cbar.GetBestSize()
+        if tbsz[0] > width:
+            width = tbsz[0]
 
         page.Freeze()
-        parent.SetClientSize((width, psz.GetHeight() + tbh))
+        parent.SetClientSize((width, psz.GetHeight() + tbsz[1]))
         parent.SendSizeEvent()
         parent.Layout()
         page.Thaw()
         if evt is not None:
             evt.Skip()
 
-    def OnPaint(self, evt):
-        """Paint the toolbar's background
-        @todo: it would be nice to use a unified toolbar style on osx
-        @note: unified toolbar is available in 2.8.5+ maybe create custom
-               window using native toolbar to accomidate this.
-
-        """
-        # This is odd but I have recieved a number of error reports where
-        # wx is being reported as None in this function
-        if 'wx' not in globals() or wx is None:
-            evt.Skip()
-            return
-
-        dc = wx.PaintDC(self)
-        gc = wx.GraphicsContext.Create(dc)
-        col1 = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
-        col2 = util.AdjustColour(col1, -10)
-        rect = self.GetToolBar().GetRect()
-
-        # Create the background path
-        path = gc.CreatePath()
-        path.AddRectangle(0, 0, rect.width, (rect.height + 3))
-
-        gc.SetPen(wx.Pen(col1, 1))
-        grad = gc.CreateLinearGradientBrush(0, 0, 0, rect.height, col1, col2)
-        gc.SetBrush(grad)
-        gc.DrawPath(path)
-
-        evt.Skip()
-
 #-----------------------------------------------------------------------------#
 
-class GeneralPanel(wx.Panel):
+class GeneralPanel(wx.Panel, PreferencesPanelBase):
     """Creates a panel with controls for Editra's general settings
     @summary: Panel with a number of controls that affect the users
               global profile setting for how Editra should operate.
 
     """
-    def __init__(self, parent):
+    def __init__(self, parent, style=wx.BORDER_SUNKEN):
         """Create the panel
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
+        PreferencesPanelBase.__init__(self)
 
         # Attributes
         self.SetToolTipString(_("Changes made in this dialog are saved in your "
@@ -275,15 +253,16 @@ class GeneralPanel(wx.Panel):
                                 "require the program to be restarted before "
                                 "taking effect."))
 
-        # Layout
-        self.__DoLayout()
+        # Layout this page right away
+        self._DoLayout()
+        self._layout_done = True
 
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CHOICE, self.OnChoice)
         self.Bind(wx.EVT_COMBOBOX, self.OnChoice)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Add the controls and do the layout
         @note: do not call this after __init__
 
@@ -355,10 +334,16 @@ class GeneralPanel(wx.Panel):
         chkmod_cb = wx.CheckBox(self, ed_glob.ID_PREF_CHKMOD,
                                 _("Check if on disk file has been "
                                   "modified by others"))
-        chkmod_cb.SetValue(Profile_Get('CHECKMOD'))
+        chkmod_val = Profile_Get('CHECKMOD', default=True)
+        chkmod_cb.SetValue(chkmod_val)
+        autorl_cb = wx.CheckBox(self, ed_glob.ID_PREF_AUTO_RELOAD,
+                                _("Automatically reload files when "
+                                  "changes are detected on disk"))
+        autorl_cb.SetValue(Profile_Get('AUTO_RELOAD', default=False) and chkmod_val)
+        autorl_cb.Enable(chkmod_val)
         eolwarn_cb = wx.CheckBox(self, ed_glob.ID_PREF_WARN_EOL,
                                  _("Warn when mixed eol characters are detected"))
-        eolwarn_cb.SetValue(Profile_Get('WARN_EOL'))
+        eolwarn_cb.SetValue(Profile_Get('WARN_EOL', default=True))
 
         # Locale
         lsizer = wx.BoxSizer(wx.HORIZONTAL)
@@ -369,7 +354,7 @@ class GeneralPanel(wx.Panel):
                          0, wx.ALIGN_CENTER_VERTICAL)])
 
         # Layout items
-        sizer = wx.FlexGridSizer(18, 2, 5, 5)
+        sizer = wx.FlexGridSizer(19, 2, 5, 5)
         sizer.AddMany([((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self,
                         label=_("Startup Settings") + u": "),
@@ -386,6 +371,7 @@ class GeneralPanel(wx.Panel):
                        ((5, 5),), (win_cb, 0),
                        ((5, 5),), (pos_cb, 0),
                        ((5, 5),), (chkmod_cb, 0),
+                       ((5, 5),), (autorl_cb, 0),
                        ((5, 5),), (eolwarn_cb, 0),
                        ((5, 5),), ((5, 5),),
                        (wx.StaticText(self, label=_("Locale Settings") + u": "),
@@ -395,8 +381,7 @@ class GeneralPanel(wx.Panel):
         msizer.AddMany([((10, 10), 0), (sizer, 1, wx.EXPAND), ((10, 10), 0)])
         self.SetSizer(msizer)
 
-    @staticmethod
-    def OnCheck(evt):
+    def OnCheck(self, evt):
         """Handles events from the check boxes
         @param evt: event that called this handler
 
@@ -405,12 +390,16 @@ class GeneralPanel(wx.Panel):
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         if e_id in (ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
-                    ed_glob.ID_PREF_CHKMOD, ed_glob.ID_SESSION,
+                    ed_glob.ID_SESSION,
                     ed_glob.ID_NEW_WINDOW, ed_glob.ID_PREF_CHKUPDATE,
-                    ed_glob.ID_PREF_WARN_EOL):
+                    ed_glob.ID_PREF_WARN_EOL, ed_glob.ID_PREF_AUTO_RELOAD):
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
         elif e_id == ed_glob.ID_REPORTER:
             Profile_Set(ed_glob.ID_2_PROF[e_id], not e_obj.GetValue())
+        elif e_id == ed_glob.ID_PREF_CHKMOD:
+            val = e_obj.GetValue()
+            Profile_Set(ed_glob.ID_2_PROF[e_id], val)
+            self.FindWindowById(ed_glob.ID_PREF_AUTO_RELOAD).Enable(val)
         else:
             pass
         evt.Skip()
@@ -441,23 +430,20 @@ class GeneralPanel(wx.Panel):
 
 #-----------------------------------------------------------------------------#
 
-class DocumentPanel(wx.Panel):
+class DocumentPanel(wx.Panel, PreferencesPanelBase):
     """Creates a panel with controls for Editra's editing settings
     @summary: Contains a wx.Notebook that contains a number of pages with
               setting controls for how documents are handled by the
               ed_stc.EditraStc text control.
 
     """
-    def __init__(self, parent):
+    def __init__(self, parent, style=wx.BORDER_SUNKEN):
         """Create the panel
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
-
-        # Attributes
-        self._DoLayout()
-        self.SetAutoLayout(True)
+        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
+        PreferencesPanelBase.__init__(self)
 
     def _DoLayout(self):
         """Do the layout of the panel
@@ -500,15 +486,15 @@ class DocGenPanel(wx.Panel):
         wx.Panel.__init__(self, parent)
 
         # Layout
-        self.__DoLayout()
+        self._DoLayout()
         self.SetAutoLayout(True)
 
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnUpdateEditor)
         self.Bind(wx.EVT_CHOICE, self.OnUpdateEditor)
-        self.Bind(ecpickers.EVT_FONT_CHANGED, self.OnFontChange)
+        self.Bind(eclib.EVT_FONT_CHANGED, self.OnFontChange)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Layout the controls
         @note: Do not call this after __init__
 
@@ -570,12 +556,12 @@ class DocGenPanel(wx.Panel):
         fnt = Profile_Get('FONT1', 'font', wx.Font(10, wx.FONTFAMILY_MODERN,
                                                    wx.FONTSTYLE_NORMAL,
                                                    wx.FONTWEIGHT_NORMAL))
-        fpick = ecpickers.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER, fnt)
+        fpick = eclib.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER, fnt)
         fpick.SetToolTipString(_("Sets the main/default font of the document"))
         fnt = Profile_Get('FONT2', 'font', wx.Font(10, wx.FONTFAMILY_SWISS,
                                                    wx.FONTSTYLE_NORMAL,
                                                    wx.FONTWEIGHT_NORMAL))
-        fpick2 = ecpickers.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER2, fnt)
+        fpick2 = eclib.PyFontPicker(self, DocGenPanel.ID_FONT_PICKER2, fnt)
         fpick2.SetToolTipString(_("Sets a secondary font used for special "
                                   "regions when syntax highlighting is in use"))
 
@@ -666,6 +652,8 @@ class DocGenPanel(wx.Panel):
         else:
             evt.Skip()
 
+#----------------------------------------------------------------------------#
+
 class DocCodePanel(wx.Panel):
     """Panel used for programming settings
     @summary: Houses many of the controls for configuring the editors features
@@ -680,7 +668,7 @@ class DocCodePanel(wx.Panel):
         wx.Panel.__init__(self, parent)
 
         # Layout
-        self.__DoLayout()
+        self._DoLayout()
         self.SetAutoLayout(True)
 
         # Event Handlers
@@ -688,7 +676,7 @@ class DocCodePanel(wx.Panel):
         self.Bind(wx.EVT_CHOICE, self.OnCheck)
         self.Bind(wx.EVT_SPINCTRL, self.OnSpin)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Layout the page
         @note: Do not call this after __init__
 
@@ -755,8 +743,7 @@ class DocCodePanel(wx.Panel):
         msizer.AddMany([((10, 10), 0), (sizer, 1, wx.EXPAND), ((10, 10), 0)])
         self.SetSizer(msizer)
 
-    @staticmethod
-    def OnCheck(evt):
+    def OnCheck(self, evt):
         """Handles the events from this panels check boxes
         @param evt: wx.CommandEvent
 
@@ -767,8 +754,19 @@ class DocCodePanel(wx.Panel):
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
                     ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE,
                     ed_glob.ID_PREF_DLEXER, ed_glob.ID_HLCARET_LINE):
-            Profile_Set(ed_glob.ID_2_PROF[e_id],
-                        evt.GetEventObject().GetValue())
+
+            e_val = evt.GetEventObject().GetValue()
+
+            # Update Profile
+            Profile_Set(ed_glob.ID_2_PROF[e_id], e_val)
+
+            # Make ui adjustments
+            if e_id == ed_glob.ID_SHOW_EDGE:
+                spin = self.FindWindowById(ed_glob.ID_PREF_EDGE)
+                if spin is not None:
+                    spin.Enable(e_val)
+
+            # Inform views of preference changes
             wx.CallLater(25, DoUpdates)
         else:
             evt.Skip()
@@ -790,6 +788,8 @@ class DocCodePanel(wx.Panel):
         else:
             evt.Skip()
 
+#----------------------------------------------------------------------------#
+
 class DocSyntaxPanel(wx.Panel):
     """Document syntax config panel
     @summary: Manages the configuration of the syntax highlighting
@@ -808,7 +808,7 @@ class DocSyntaxPanel(wx.Panel):
         self._elist.SetMinSize((425, 200))
 
         # Layout page
-        self.__DoLayout()
+        self._DoLayout()
         self.SetAutoLayout(True)
 
         # Event Handlers
@@ -816,7 +816,7 @@ class DocSyntaxPanel(wx.Panel):
         self.Bind(wx.EVT_CHECKBOX, self.OnSynChange)
         self.Bind(wx.EVT_CHOICE, self.OnSynChange)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Layout all the controls
         @note: Do not call this after __init__
 
@@ -899,28 +899,26 @@ class DocSyntaxPanel(wx.Panel):
 
 #-----------------------------------------------------------------------------#
 
-class AppearancePanel(wx.Panel):
+class AppearancePanel(wx.Panel, PreferencesPanelBase):
     """Creates a panel with controls for Editra's appearance settings
     @summary: contains all the controls for configuring the appearance
               related settings in Editra.
 
     """
-    def __init__(self, parent):
+    def __init__(self, parent, style=wx.BORDER_SUNKEN):
         """Create the panel
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
-
-        # Layout
-        self._DoLayout()
+        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
+        PreferencesPanelBase.__init__(self)
 
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CHOICE, self.OnChoice)
         self.Bind(wx.EVT_SLIDER, self.OnSetTransparent, \
                   id=ed_glob.ID_TRANSPARENCY)
-        self.Bind(ed_event.EVT_NOTIFY, self.OnFontChange)
+        self.Bind(eclib.EVT_FONT_CHANGED, self.OnFontChange)
 
     def _DoLayout(self):
         """Add and layout the widgets
@@ -971,14 +969,9 @@ class AppearancePanel(wx.Panel):
 
         # Font
         fnt = Profile_Get('FONT3', 'font', wx.NORMAL_FONT)
-        fpick = ecpickers.PyFontPicker(self, wx.ID_ANY, fnt)
+        fpick = eclib.PyFontPicker(self, wx.ID_ANY, fnt)
         fpick.SetToolTipString(_("Main display font for various UI components"))
 
-        # Misc
-        trans_size = (-1, -1)
-        if wx.Platform == '__WXGTK__':
-            trans_size = (200, 15)
-
         # Layout
         sizer = wx.FlexGridSizer(16, 2, 5, 5)
         sizer.AddMany([((10, 10), 0), ((10, 10), 0),
@@ -998,8 +991,8 @@ class AppearancePanel(wx.Panel):
                        (wx.StaticText(self, label=_("Transparency") + u": "), 0),
                        (wx.Slider(self, ed_glob.ID_TRANSPARENCY,
                                    Profile_Get('ALPHA'), 100, 255,
-                                   size=trans_size, style=wx.SL_HORIZONTAL | \
-                                   wx.SL_AUTOTICKS | wx.SL_LABELS), 0, wx.EXPAND),
+                                   style=wx.SL_HORIZONTAL|wx.SL_AUTOTICKS|\
+                                         wx.SL_LABELS), 0, wx.EXPAND),
                        ((10, 10), 0), ((10, 10), 0),
                        (wx.StaticText(self, label=_("Display Font") + u": "),
                         0, wx.ALIGN_CENTER_VERTICAL),
@@ -1087,17 +1080,14 @@ class AppearancePanel(wx.Panel):
 
 #-----------------------------------------------------------------------------#
 
-class NetworkPanel(wx.Panel):
+class NetworkPanel(wx.Panel, PreferencesPanelBase):
     """Network related configration options"""
-    def __init__(self, parent):
+    def __init__(self, parent, style=wx.BORDER_SUNKEN):
         """Create the panel"""
-        wx.Panel.__init__(self, parent)
+        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
+        PreferencesPanelBase.__init__(self)
 
-        # Layout
-        self.__DoLayout()
-        self.SetAutoLayout(True)
-
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Do the layout of the panel
         @note: Do not call this after __init__
 
@@ -1125,13 +1115,14 @@ class NetConfigPage(wx.Panel):
         wx.Panel.__init__(self, parent)
 
         # Layout
-        self.__DoLayout()
+        self._DoLayout()
+        self.SetAutoLayout(True)
 
         # Event Handlers
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck, id=ID_USE_PROXY)
         self.Bind(wx.EVT_BUTTON, self.OnApply, id=wx.ID_APPLY)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Layout the controls in the panel"""
         msizer = wx.BoxSizer(wx.VERTICAL)
 
@@ -1253,13 +1244,13 @@ class UpdatePage(wx.Panel):
         wx.Panel.__init__(self, parent)
 
         # Layout
-        self.__DoLayout()
+        self._DoLayout()
 
         # Event Handlers
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(ed_event.EVT_UPDATE_TEXT, self.OnUpdateText)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Do the layout of the panel
         @note: Do not call this after __init__
 
@@ -1360,18 +1351,17 @@ class AdvancedPanel(wx.Panel):
               options.
 
     """
-    def __init__(self, parent):
+    def __init__(self, parent, style=wx.BORDER_SUNKEN):
         """Create the panel
         @param parent: Parent window of this panel
 
         """
-        wx.Panel.__init__(self, parent)
+        wx.Panel.__init__(self, parent, style=wx.BORDER_SUNKEN)
 
         # Layout
-        self.__DoLayout()
-        self.SetAutoLayout(True)
+        self._layout_done = False
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Do the layout of the panel
         @note: Do not call this after __init__
 
@@ -1384,6 +1374,13 @@ class AdvancedPanel(wx.Panel):
         msizer.AddMany([(sizer, 1, wx.EXPAND), ((10, 10), 0)])
         self.SetSizer(msizer)
 
+    def DoSelected(self):
+        """Handle initial selection to create controls"""
+        if not self._layout_done:
+            self._layout_done = True
+            self._DoLayout()
+            self.SetAutoLayout(True)
+
 #-----------------------------------------------------------------------------#
 # Keybinding Panel
 
@@ -1437,14 +1434,14 @@ class KeyBindingPanel(wx.Panel):
                 self.menumap[key] = sorted(val, _tupSort)
 
         # Layout
-        self.__DoLayout()
+        self._DoLayout()
 
         # Event Handlers
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CHOICE, self.OnChoice)
         self.Bind(wx.EVT_LISTBOX, self.OnListBox)
 
-    def __DoLayout(self):
+    def _DoLayout(self):
         """Layout the controls"""
         msizer = wx.BoxSizer(wx.VERTICAL) # Main Sizer
         spacer = ((5, 5), 0)
@@ -1772,10 +1769,11 @@ class KeyBindingPanel(wx.Panel):
             evt.Skip()
 
 #----------------------------------------------------------------------------#
+
 class ExtListCtrl(wx.ListCtrl,
                   listmix.ListCtrlAutoWidthMixin,
                   listmix.TextEditMixin,
-                  elistmix.ListRowHighlighter):
+                  eclib.ListRowHighlighter):
     """Class to manage the file extension associations
     @summary: Creates a list control for showing file type to file extension
               associations as well as providing an interface to editing these
@@ -1795,7 +1793,7 @@ class ExtListCtrl(wx.ListCtrl,
                                    wx.LC_VRULES | wx.BORDER)
 
         listmix.ListCtrlAutoWidthMixin.__init__(self)
-        elistmix.ListRowHighlighter.__init__(self)
+        eclib.ListRowHighlighter.__init__(self)
 
         # Setup
         self.InsertColumn(ExtListCtrl.FILE_COL, _("Lexer"))
@@ -1868,6 +1866,7 @@ class ExtListCtrl(wx.ListCtrl,
                                u'  ' + u' '.join(self._extreg[ftype]))
 
 #----------------------------------------------------------------------------#
+
 class ExChoice(wx.Choice):
     """Class to extend wx.Choice to have the GetValue
     function. This allows the application function to remain
