@@ -17,8 +17,8 @@ editor can load to configure the styles of the text.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 56787 2008-11-15 23:37:01Z CJP $"
-__revision__ = "$Revision: 56787 $"
+__svnid__ = "$Id: style_editor.py 59714 2009-03-22 01:31:07Z CJP $"
+__revision__ = "$Revision: 59714 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -29,11 +29,11 @@ import wx
 # Editra Imports
 import ed_glob
 from profiler import Profile_Get, Profile_Set
-import ed_stc
+import ed_basestc
 from ed_style import StyleItem
 import util
 import syntax.syntax as syntax
-import eclib.colorsetter as colorsetter
+import eclib
 
 # Function Aliases
 _ = wx.GetTranslation
@@ -70,8 +70,8 @@ class StyleEditor(wx.Dialog):
 
         # Attributes
         self.LOG = wx.GetApp().GetLog()
-        self.preview = ed_stc.EditraStc(self, wx.ID_ANY, size=(-1, 200),
-                                        style=wx.SUNKEN_BORDER, use_dt=False)
+        self.preview = ed_basestc.EditraBaseStc(self, wx.ID_ANY, size=(-1, 200),
+                                                style=wx.SUNKEN_BORDER)
         self.styles_orig = self.preview.GetStyleSet()
         self.preview.SetCaretLineVisible(True)
         self.styles_new = DuplicateStyleDict(self.styles_orig)
@@ -157,7 +157,7 @@ class StyleEditor(wx.Dialog):
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
         self.Bind(wx.EVT_LISTBOX, self.OnListBox)
-        self.Bind(colorsetter.EVT_COLORSETTER, self.OnColor)
+        self.Bind(eclib.EVT_COLORSETTER, self.OnColor)
         self.preview.Bind(wx.EVT_LEFT_UP, self.OnTextRegion)
         self.preview.Bind(wx.EVT_KEY_UP, self.OnTextRegion)
     #--- End Init ---#
@@ -281,15 +281,20 @@ class StyleEditor(wx.Dialog):
                 else:
                     ed_glob.CONFIG['STYLES_DIR'] = user_config
 
-        dlg = wx.FileDialog(self, _("Export Style Sheet"),
-                            ed_glob.CONFIG['STYLES_DIR'],
-                            wildcard=_("Editra Style Sheet") + " (*.ess)|*.ess",
-                            style=wx.FD_SAVE | wx.OVERWRITE_PROMPT)
-        dlg.CenterOnParent()
-        result = dlg.ShowModal()
+        result = wx.ID_CANCEL
+        ss_c = self.FindWindowById(ed_glob.ID_PREF_SYNTHEME)
+        new_cb = self.FindWindowById(wx.ID_NEW)
+        if new_cb.GetValue():
+            name = ''
+        else:
+            name = ss_c.GetStringSelection()
 
-        if result == wx.ID_OK:
-            sheet_path = dlg.GetPath()
+        fname = wx.GetTextFromUser(_("Enter style sheet name"),
+                                   _("Export Style Sheet"),
+                                   name, self)
+
+        if len(fname):
+            sheet_path = os.path.join(ed_glob.CONFIG['STYLES_DIR'], fname)
             if sheet_path.split(u'.')[-1] != u'ess':
                 sheet_path += u".ess"
 
@@ -303,19 +308,19 @@ class StyleEditor(wx.Dialog):
             else:
                 # Update Style Sheet Control
                 sheet = ".".join(os.path.basename(sheet_path).split(u'.')[:-1])
-                ss_c = self.FindWindowById(ed_glob.ID_PREF_SYNTHEME)
                 ss_c.SetItems(util.GetResourceFiles(u'styles', get_all=True))
                 ss_c.SetStringSelection(sheet)
                 ss_c.Enable()
                 self.FindWindowById(wx.ID_NEW).SetValue(False)
                 self.styles_orig = self.styles_new
                 self.styles_new = DuplicateStyleDict(self.styles_orig)
+                result = wx.ID_OK
 
                 if sheet_path.startswith(ed_glob.CONFIG['STYLES_DIR']) or \
                    sheet_path.startswith(ed_glob.CONFIG['SYS_STYLES_DIR']):
                     # Update editor windows/buffer to use new style sheet
                     UpdateBufferStyles(sheet)
-        dlg.Destroy()
+
         return result
 
     def GenerateStyleSheet(self):
@@ -451,7 +456,7 @@ class StyleEditor(wx.Dialog):
         style_id = self.preview.GetStyleAt(self.preview.GetCurrentPos())
         tag_lst = self.FindWindowById(ID_STYLES)
         data = self.preview.FindTagById(style_id)
-        if data != wx.EmptyString and self.styles_new.has_key(data):
+        if data != wx.EmptyString and data in self.styles_new:
             tag_lst.SetStringSelection(data)
             if wx.Platform == '__WXGTK__':
                 tag_lst.SetFirstItemStr(data)
@@ -465,7 +470,7 @@ class StyleEditor(wx.Dialog):
 
         """
         tag = evt.GetEventObject().GetStringSelection()
-        if tag != wx.EmptyString and self.styles_new.has_key(tag):
+        if tag != wx.EmptyString and tag in self.styles_new:
             self.UpdateSettingsPane(self.styles_new[tag])
             self.EnableSettings()
         else:
@@ -553,7 +558,7 @@ class StyleEditor(wx.Dialog):
                 ctrl.SetValue(val_map[sid])
             elif c_type == "wxChoice":
                 ctrl.SetStringSelection(val_map[sid])
-            elif isinstance(ctrl, colorsetter.ColorSetter):
+            elif isinstance(ctrl, eclib.ColorSetter):
                 ctrl.SetLabel(val_map[sid][:7])
         return True
 
@@ -576,7 +581,7 @@ class StyleEditor(wx.Dialog):
             val = ctrl.GetValue()
         elif ctrl_t == 'wxChoice':
             val = ctrl.GetStringSelection()
-        elif isinstance(ctrl, colorsetter.ColorSetter):
+        elif isinstance(ctrl, eclib.ColorSetter):
             val = ctrl.GetLabel()
         else:
             return False
@@ -632,7 +637,7 @@ class SettingsPanel(wx.Panel):
         # Foreground
         fground_sizer = wx.BoxSizer(wx.HORIZONTAL)
         fground_lbl = wx.StaticText(self, label=_("Foreground") + u": ")
-        fground_sel = colorsetter.ColorSetter(self, ID_FORE_COLOR, wx.BLACK)
+        fground_sel = eclib.ColorSetter(self, ID_FORE_COLOR, wx.BLACK)
         fground_sizer.AddMany([((5, 5)),
                                (fground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
                                ((2, 2), 1, wx.EXPAND),
@@ -644,7 +649,7 @@ class SettingsPanel(wx.Panel):
         # Background
         bground_sizer = wx.BoxSizer(wx.HORIZONTAL)
         bground_lbl = wx.StaticText(self, label=_("Background") + u": ")
-        bground_sel = colorsetter.ColorSetter(self, ID_BACK_COLOR, wx.WHITE)
+        bground_sel = eclib.ColorSetter(self, ID_BACK_COLOR, wx.WHITE)
         bground_sizer.AddMany([((5, 5)),
                                (bground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
                                ((2, 2), 1, wx.EXPAND),
