@@ -19,8 +19,8 @@ threads to interact with the buffer.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: OutputBufferDemo.py 52085 2008-02-25 07:56:16Z CJP $"
-__revision__ = "$Revision: 52085 $"
+__svnid__ = "$Id: OutputBufferDemo.py 56206 2008-10-10 02:32:23Z CJP $"
+__revision__ = "$Revision: 56206 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -104,7 +104,7 @@ class TestPanel(wx.Panel):
         elif e_id == ID_START:
             # Spawn a new ProcessThread
             combo = self.FindWindowById(ID_COMMAND)
-            self._buff.StartProcess('%s' % combo.GetValue())
+            self._buff.StartProcess(u'%s' % combo.GetValue())
             self.UpdateProcs()
         else:
             evt.Skip()
@@ -285,8 +285,10 @@ if __name__ == '__main__':
         sizer.Add(TestPanel(frame, TestLog()), 1, wx.EXPAND)
         frame.CreateStatusBar()
         frame.SetSizer(sizer)
-        frame.SetInitialSize()
-        frame.SetStatusText("OutputBuffer test")
+        frame.SetInitialSize((500, 500))
+        frame.SetStatusText("OutputBufferDemo: wxPython %s, Python %s" % \
+                            (wx.__version__, u".".join(str(x) for x in sys.version_info)))
+        frame.CenterOnParent()
         frame.Show()
         app.MainLoop()
     else:
